# coding:utf8

"""French dictionary"""

# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN

fr = {
    "LANGUAGE": "Français",
    "LANGUAGE-TAG": "fr",

    # Strings for Windows NSIS installer
    "installer-language-file": "French.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
    "installer-associate": "Associer Syncplay avec les fichiers multimedias.",
    "installer-shortcut": "Créer Racourcis pour les chemins suivants:",
    "installer-start-menu": "Menu Démarrer",
    "installer-desktop": "Bureau",
    "installer-quick-launch-bar": "Barre de Lancement Rapide",
    "installer-automatic-updates": "Vérifier automatiquement les mises à jour",
    "installer-uninstall-configuration": "Supprimer le fichier de configuration.",

    # Client notifications
    "config-cleared-notification": "Paramètres effacés. Les modifications seront enregistrées lorsque vous enregistrez une configuration valide.",

    "relative-config-notification": "Fichiers de configuration relatifs chargés: {}",

    "connection-attempt-notification": "Tentative de connexion à {}:{}",  # Port, IP
    "reconnection-attempt-notification": "Connexion avec le serveur perdue, tentative de reconnexion",
    "disconnection-notification": "Déconnecté du serveur",
    "connection-failed-notification": "Échec de la connexion avec le serveur",
    "connected-successful-notification": "Connexion réussie au serveur",
    "retrying-notification": "%s, nouvelle tentative dans %d secondes...",  # Seconds
    "reachout-successful-notification": "Vous avez atteint {} ({})",

    "rewind-notification": "Retour en arrière en raison du décalage de temps avec {}",  # User
    "fastforward-notification": "Avance rapide en raison du décalage de temps avec {}",  # User
    "slowdown-notification": "Ralentissement dû au décalage de temps avec {}",  # User
    "revert-notification": "Retour à la vitesse normale",

    "pause-notification": "{} en pause ({})",  # User, Time - TODO: Change into format "{} paused at {}" in line with English message
    "unpause-notification": "{} non suspendu",  # User
    "seek-notification": "{} est passé de {} à {}",  # User, from time, to time

    "current-offset-notification": "Décalage actuel: {}secondes",  # Offset

    "media-directory-list-updated-notification": "Les répertoires multimédias Syncplay ont été mis à jour.",

    "room-join-notification": "{} a rejoint la salle: '{}'",  # User
    "left-notification": "{} est parti",  # User
    "left-paused-notification": "{} restants, {} en pause",  # User who left, User who paused
    "playing-notification": "{} est en train de jouer '{}' ({})",  # User, file, duration
    "playing-notification/room-addendum": "dans le salon: '{}'",  # Room

    "not-all-ready": "Pas prêt: {}",  # Usernames
    "all-users-ready": "Tout le monde est prêt ({} utilisateurs)",  # Number of ready users
    "ready-to-unpause-notification": "Vous êtes maintenant défini comme prêt - réactivez la pause pour réactiver",
    "set-as-ready-notification": "Vous êtes maintenant défini comme prêt",
    "set-as-not-ready-notification": "Vous êtes maintenant défini comme non prêt",
    "autoplaying-notification": "Lecture automatique dans {}...",  # Number of seconds until playback will start

    "identifying-as-controller-notification": "Identification en tant qu'opérateur de salle avec le mot de passe '{}'...",
    "failed-to-identify-as-controller-notification": "{} n'a pas réussi à s'identifier en tant qu'opérateur de salle.",
    "authenticated-as-controller-notification": "{} authentifié en tant qu'opérateur de salle",
    "created-controlled-room-notification": "Salle gérée créée «{}» avec le mot de passe «{}». Veuillez conserver ces informations pour référence future !\n\nDans les salons gérés, tout le monde est synchronisé avec le ou les opérateurs de salon qui sont les seuls à pouvoir mettre en pause, reprendre, se déplacer dans la lecture et modifier la liste de lecture.\n\nVous devez demander aux spectateurs réguliers de rejoindre le salon '{}' mais les opérateurs de salon peuvent rejoindre le salon '{}' pour s'authentifier automatiquement.",  # RoomName, operatorPassword, roomName, roomName:operatorPassword

    "other-set-as-ready-notification": "{} was set as ready by {}", # User set as ready, user who set them as ready # TODO: Translate
    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate

    "file-different-notification": "Le fichier que vous lisez semble être différent de celui de {}",  # User
    "file-differences-notification": "Votre fichier diffère de la (des) manière(s) suivante(s): {}",  # Differences
    "room-file-differences": "Différences de fichiers: {}",  # File differences (filename, size, and/or duration)
    "file-difference-filename": "Nom",
    "file-difference-filesize": "Taille",
    "file-difference-duration": "durée",
    "alone-in-the-room": "Vous êtes seul dans le salon",

    "different-filesize-notification": "(leur taille de fichier est différente de la vôtre!)",
    "userlist-playing-notification": "{} est en train de jouer:",  # Username
    "file-played-by-notification": "Fichier: {} est lu par:",  # File
    "no-file-played-notification": "{} ne lit pas de fichier",  # Username
    "notplaying-notification": "Les personnes qui ne lisent aucun fichier:",
    "userlist-room-notification": "Dans la chambre '{}':",  # Room
    "userlist-file-notification": "Fichier",
    "controller-userlist-userflag": "Opérateur",
    "ready-userlist-userflag": "Prêt",

    "update-check-failed-notification": "Impossible de vérifier automatiquement si Syncplay {} est à jour. Vous voulez visiter https://syncplay.pl/ pour vérifier manuellement les mises à jour?",  # Syncplay version
    "syncplay-uptodate-notification": "Syncplay est à jour",
    "syncplay-updateavailable-notification": "Une nouvelle version de Syncplay est disponible. Voulez-vous visiter la page de publication?",

    "mplayer-file-required-notification": "Syncplay à l'aide de mplayer nécessite que vous fournissiez un fichier au démarrage",
    "mplayer-file-required-notification/example": "Exemple d'utilisation: syncplay [options] [url|chemin/]nom de fichier",
    "mplayer2-required": "Syncplay est incompatible avec MPlayer 1.x, veuillez utiliser mplayer2 ou mpv",

    "unrecognized-command-notification": "commande non reconnue",
    "commandlist-notification": "Commandes disponibles:",
    "commandlist-notification/room": "\tr [nom] - changer de chambre",
    "commandlist-notification/list": "\tl - afficher la liste des utilisateurs",
    "commandlist-notification/undo": "\tu - annuler la dernière recherche",
    "commandlist-notification/pause": "\tp - basculer sur pause",
    "commandlist-notification/seek": "\t[s][+-]temps - recherche la valeur de temps donnée, si + ou - n'est pas spécifié c'est le temps absolu en secondes ou min:sec",
    "commandlist-notification/offset": "\to[+-]duration - offset local playback by the given duration (in seconds or min:sec) from the server seek position - this is a deprecated feature", # TODO: Translate
    "commandlist-notification/help": "\th - cette aide",
    "commandlist-notification/toggle": "\tt - bascule si vous êtes prêt à regarder ou non",
    "commandlist-notification/setready": "\tsr [name] - sets user as ready",  # TODO: Translate
    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready",  # TODO: Translate
    "commandlist-notification/create": "\tc [nom] - crée une salle gérée en utilisant le nom de la salle actuelle",
    "commandlist-notification/auth": "\tun [mot de passe] - s'authentifier en tant qu'opérateur de salle avec le mot de passe opérateur",
    "commandlist-notification/chat": "\tch [message] - envoyer un message de chat dans une pièce",
    "commandList-notification/queue": "\tqa [fichier/url] - ajoute un fichier ou une URL au bas de la liste de lecture",
    "commandList-notification/queueandselect": "\tqas [file/url] - add file or url to bottom of playlist and select it", # TODO: Translate
    "commandList-notification/playlist": "\tql - afficher la liste de lecture actuelle",
    "commandList-notification/select": "\tqs [index] - sélectionnez l'entrée donnée dans la liste de lecture",
    "commandList-notification/next": "\tqn - select next entry in the playlist", # TODO: Translate
    "commandList-notification/delete": "\tqd [index] - supprime l'entrée donnée de la liste de lecture",
    "syncplay-version-notification": "Version de Syncplay: {}",  # syncplay.version
    "more-info-notification": "Plus d'informations disponibles sur: {}",  # projectURL

    "gui-data-cleared-notification": "Syncplay a effacé les données d'état de chemin et de fenêtre utilisées par l'interface graphique.",
    "language-changed-msgbox-label": "La langue sera modifiée lorsque vous exécuterez Syncplay.",
    "promptforupdate-label": "Est-ce que Syncplay peut vérifier automatiquement les mises à jour de temps en temps?",

    "media-player-latency-warning": "Avertissement: Le lecteur multimédia a mis {}secondes à répondre. Si vous rencontrez des problèmes de synchronisation, fermez les applications pour libérer des ressources système, et si cela ne fonctionne pas, essayez un autre lecteur multimédia.",  # Seconds to respond
    "mpv-unresponsive-error": "mpv n'a pas répondu pendant {} secondes et semble donc avoir mal fonctionné. Veuillez redémarrer Syncplay.",  # Seconds to respond

    # Client prompts
    "enter-to-exit-prompt": "Appuyez sur entrée pour quitter",

    # Client errors
    "missing-arguments-error": "Certains arguments nécessaires sont manquants, reportez-vous à --help",
    "server-timeout-error": "La connexion avec le serveur a expiré",
    "mpc-slave-error": "Impossible de démarrer MPC en mode esclave!",
    "mpc-version-insufficient-error": "La version MPC n'est pas suffisante, veuillez utiliser `mpc-hc` >= `{}`",
    "mpc-be-version-insufficient-error": "La version MPC n'est pas suffisante, veuillez utiliser `mpc-be` >= `{}`",
    "mpv-version-error": "Syncplay n'est pas compatible avec cette version de mpv. Veuillez utiliser une version différente de mpv (par exemple Git HEAD).",
    "mpv-failed-advice": "La raison pour laquelle mpv ne peut pas démarrer peut être due à l'utilisation d'arguments de ligne de commande non pris en charge ou à une version non prise en charge de mpv.",
    "player-file-open-error": "Le lecteur n'a pas réussi à ouvrir le fichier",
    "player-path-error": "Le chemin du lecteur n'est pas défini correctement. Les lecteurs pris en charge sont : mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 et IINA",
    "hostname-empty-error": "Le nom d'hôte ne peut pas être vide",
    "empty-error": "{} ne peut pas être vide",  # Configuration
    "media-player-error": "Media player error: \"{}\"",  # Error line
    "unable-import-gui-error": "Impossible d'importer les bibliothèques GUI. Si vous n'avez pas installé PySide, vous devrez l'installer pour que l'interface graphique fonctionne. If you want to run Syncplay in console mode then run it with the --no-gui command line switch. See https://syncplay.pl/guide/ for more details.", # TODO: Translate end of message and update second sentence to be a translation of "You need to have the correct version of PySide installed for the GUI to work."
    "unable-import-twisted-error": "Impossible d'importer Twisted. Veuillez installer Twisted v16.4.0 ou une version ultérieure.",

    "arguments-missing-error": "Certains arguments nécessaires sont manquants, reportez-vous à --help",

    "unable-to-start-client-error": "Impossible de démarrer le client",

    "player-path-config-error": "Le chemin du lecteur n'est pas défini correctement. Les lecteurs pris en charge sont : mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 et IINA.",
    "no-file-path-config-error": "Le fichier doit être sélectionné avant de démarrer votre lecteur",
    "no-hostname-config-error": "Le nom d'hôte ne peut pas être vide",
    "invalid-port-config-error": "Le port doit être valide",
    "empty-value-config-error": "{} ne peut pas être vide",  # Config option

    "not-json-error": "Pas une chaîne encodée en json",
    "hello-arguments-error": "Pas assez d'arguments pour Hello",  # DO NOT TRANSLATE
    "version-mismatch-error": "Non-concordance entre les versions du client et du serveur",
    "vlc-failed-connection": "Échec de la connexion à VLC. Si vous n'avez pas installé syncplay.lua et utilisez la dernière version de VLC, veuillez vous référer à https://syncplay.pl/LUA/ pour obtenir des instructions. Syncplay et VLC 4 ne sont actuellement pas compatibles, utilisez donc VLC 3 ou une alternative telle que mpv.",
    "vlc-failed-noscript": "VLC a signalé que le script d'interface syncplay.lua n'a pas été installé. Veuillez vous référer à https://syncplay.pl/LUA/ pour obtenir des instructions.",
    "vlc-failed-versioncheck": "Cette version de VLC n'est pas prise en charge par Syncplay.",
    "vlc-initial-warning": "VLC ne fournit pas toujours des informations de position précises à Syncplay, en particulier pour les fichiers .mp4 et .avi. Si vous rencontrez des problèmes de recherche erronée, essayez un autre lecteur multimédia tel que <a href=\"https://mpv.io/\">mpv</a> (ou <a href=\"https://github.com/stax76/mpv.net/\">mpv.net</a> pour les utilisateurs de Windows).",

    "feature-sharedPlaylists": "listes de lecture partagées",  # used for not-supported-by-server-error
    "feature-chat": "chat",  # used for not-supported-by-server-error
    "feature-readiness": "préparation",  # used for not-supported-by-server-error
    "feature-managedRooms": "salons gérés",  # used for not-supported-by-server-error
    "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate

    "not-supported-by-server-error": "La fonctionnalité {} n'est pas prise en charge par ce serveur.",  # feature
    "shared-playlists-not-supported-by-server-error": "La fonctionnalité de listes de lecture partagées peut ne pas être prise en charge par le serveur. Pour s'assurer qu'il fonctionne correctement, il faut un serveur exécutant Syncplay {}+, mais le serveur exécute Syncplay {}.",  # minVersion, serverVersion
    "shared-playlists-disabled-by-server-error": "La fonctionnalité de liste de lecture partagée a été désactivée dans la configuration du serveur. Pour utiliser cette fonctionnalité, vous devrez vous connecter à un autre serveur.",

    "invalid-seek-value": "Valeur de recherche non valide",
    "invalid-offset-value": "Valeur de décalage non valide",

    "switch-file-not-found-error": "Impossible de passer au fichier ''. Syncplay recherche dans les répertoires multimédias spécifiés.",  # File not found
    "folder-search-timeout-error": "La recherche de médias dans les répertoires de médias a été abandonnée car la recherche dans '{}' a pris trop de temps (after having processed the first {:,} files). Cela se produira si vous sélectionnez un dossier avec trop de sous-dossiers dans votre liste de dossiers multimédias à parcourir. Pour que le basculement automatique des fichiers fonctionne à nouveau, veuillez sélectionner Fichier->Définir les répertoires multimédias dans la barre de menu et supprimez ce répertoire ou remplacez-le par un sous-dossier approprié. Si le dossier est correct, vous pouvez le réactiver en sélectionnant Fichier->Définir les répertoires multimédias et en appuyant sur «OK».", # Folder, Files processed - Note: {:,} is {} but with added commas seprators - TODO: Translate
    "folder-search-timeout-warning": "Warning: It has taken {} seconds to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
    "folder-search-first-file-timeout-error": "La recherche de média dans '{}' a été abandonnée car elle a pris trop de temps pour accéder au répertoire. Cela peut arriver s'il s'agit d'un lecteur réseau ou si vous configurez votre lecteur pour qu'il ralentisse après une période d'inactivité. Pour que le basculement automatique des fichiers fonctionne à nouveau, accédez à Fichier-> Définir les répertoires multimédias et supprimez le répertoire ou résolvez le problème (par exemple en modifiant les paramètres d'économie d'énergie).",  # Folder
    "added-file-not-in-media-directory-error": "Vous avez chargé un fichier dans '{}' qui n'est pas un répertoire média connu. Vous pouvez l'ajouter en tant que répertoire multimédia en sélectionnant Fichier->Définir les répertoires multimédias dans la barre de menus.",  # Folder
    "no-media-directories-error": "Aucun répertoire multimédia n'a été défini. Pour que les fonctionnalités de liste de lecture partagée et de changement de fichier fonctionnent correctement, sélectionnez Fichier-> Définir les répertoires multimédias et spécifiez où Syncplay doit rechercher les fichiers multimédias.",
    "cannot-find-directory-error": "Impossible de trouver le répertoire multimédia '{}'. Pour mettre à jour votre liste de répertoires multimédias, veuillez sélectionner Fichier->Définir les répertoires multimédias dans la barre de menu et spécifiez où Syncplay doit chercher pour trouver les fichiers multimédias.",

    "failed-to-load-server-list-error": "Échec du chargement de la liste des serveurs publics. Veuillez visiter https://www.syncplay.pl/ dans votre navigateur.",

    # Client arguments
    "argument-description": "Solution pour synchroniser la lecture de plusieurs instances de lecteur multimédia sur le réseau.",
    "argument-epilog": "Si aucune option n'est fournie, les valeurs _config seront utilisées",
    "nogui-argument": "masquer l'interface graphique",
    "host-argument": "adresse du serveur",
    "name-argument": "nom d'utilisateur souhaité",
    "debug-argument": "Mode débogage",
    "force-gui-prompt-argument": "faire apparaître l'invite de configuration",
    "no-store-argument": "ne pas stocker de valeurs dans .syncplay",
    "room-argument": "salon par défaut",
    "password-argument": "Mot de passe du serveur",
    "player-path-argument": "chemin d'accès à l'exécutable de votre lecteur",
    "file-argument": "fichier à lire",
    "args-argument": 'player options, if you need to pass options starting with - prepend them with single \'--\' argument',
    "clear-gui-data-argument": "réinitialise les données GUI du chemin et de l'état de la fenêtre stockées en tant que QSettings",
    "language-argument": "langue pour les messages Syncplay ({})", # Languages

    "version-argument": "imprime votre version",
    "version-message": "Vous utilisez Syncplay version {} ({})",

    "load-playlist-from-file-argument": "charge la liste de lecture à partir d'un fichier texte (une entrée par ligne)",


    # Client labels
    "config-window-title": "configuration Syncplay",

    "connection-group-title": "Paramètres de connexion",
    "host-label": "Adresse du serveur:",
    "name-label": "Nom d'utilisateur (facultatif):",
    "password-label": "Mot de passe du serveur (le cas échéant):",
    "room-label": "Salon par défaut:",
    "roomlist-msgbox-label": "Modifier la liste des salons (une par ligne)",

    "media-setting-title": "Paramètres du lecteur multimédia",
    "executable-path-label": "Chemin d'accès au lecteur multimédia:",
    "media-path-label": "Chemin d'accès à la vidéo (facultatif):",
    "player-arguments-label": "Arguments du joueur (le cas échéant):",
    "browse-label": "Parcourir",
    "update-server-list-label": "Mettre à jour la liste",

    "more-title": "Afficher plus de paramètres",
    "never-rewind-value": "Jamais",
    "seconds-suffix": "secs",
    "privacy-sendraw-option": "Envoyer brut",
    "privacy-sendhashed-option": "Envoyer haché",
    "privacy-dontsend-option": "Ne pas envoyer",
    "filename-privacy-label": "Informations sur le nom de fichier:",
    "filesize-privacy-label": "Informations sur la taille du fichier:",
    "checkforupdatesautomatically-label": "Rechercher automatiquement les mises à jour de Syncplay",
    "autosavejoinstolist-label": "Ajouter les salons que vous rejoignez à la liste des salons",
    "slowondesync-label": "Ralentissement en cas de désynchronisation mineure (non pris en charge sur MPC-HC/BE)",
    "rewindondesync-label": "Retour en arrière en cas de désynchronisation majeure (recommandé)",
    "fastforwardondesync-label": "Avance rapide en cas de retard (recommandé)",
    "dontslowdownwithme-label": "Ne jamais ralentir ou rembobiner les autres (expérimental)",
    "pausing-title": "Pause",
    "pauseonleave-label": "Pause lorsque l'utilisateur quitte (par exemple s'il est déconnecté)",
    "readiness-title": "État de préparation initial",
    "readyatstart-label": "Définissez-moi comme «prêt à regarder» par défaut",
    "forceguiprompt-label": "Ne pas toujours afficher la fenêtre de configuration Syncplay",  # (Inverted)
    "showosd-label": "Activer les Messages OSD",

    "showosdwarnings-label": "Inclure des avertissements (par exemple, lorsque les fichiers sont différents, les utilisateurs ne sont pas prêts)",
    "showsameroomosd-label": "Inclure des événements dans votre salon",
    "shownoncontrollerosd-label": "Inclure les événements des non-opérateurs dans les salons gérés",
    "showdifferentroomosd-label": "Inclure des événements dans d'autres salons",
    "showslowdownosd-label": "Inclure les notifications de ralentissement/annulation",
    "language-label": "Langue:",
    "automatic-language": "Défaut ({})",  # Default language
    "showdurationnotification-label": "Avertir des incohérences de durée de média",
    "basics-label": "Réglages de base",
    "readiness-label": "Jouer pause",
    "misc-label": "Divers",
    "core-behaviour-title": "Comportement du salon principal",
    "syncplay-internals-title": "procédures internes",
    "syncplay-mediasearchdirectories-title": "Répertoires pour rechercher des médias",
    "syncplay-mediasearchdirectories-label": "Répertoires pour rechercher des médias (un chemin par ligne)",
    "sync-label": "Synchroniser",
    "sync-otherslagging-title": "Si d'autres sont à la traîne...",
    "sync-youlaggging-title": "Si vous êtes à la traîne...",
    "messages-label": "Messages",
    "messages-osd-title": "Paramètres d'affichage à l'écran",
    "messages-other-title": "Autres paramètres d'affichage",
    "chat-label": "Chat",
    "privacy-label": "Sécurité données",  # Currently unused, but will be brought back if more space is needed in Misc tab
    "privacy-title": "Paramètres de confidentialité",
    "unpause-title": "Si vous appuyez sur play, définissez comme prêt et:",
    "unpause-ifalreadyready-option": "Annuler la pause si déjà défini comme prêt",
    "unpause-ifothersready-option": "Reprendre la pause si déjà prêt ou si d'autres personnes dans la pièce sont prêtes (par défaut)",
    "unpause-ifminusersready-option": "Annuler la pause si déjà prêt ou si tous les autres sont prêts et utilisateurs minimum prêts",
    "unpause-always": "Toujours reprendre",
    "syncplay-trusteddomains-title": "Domaines de confiance (pour les services de streaming et le contenu hébergé)",

    "chat-title": "Saisie du message de discussion",
    "chatinputenabled-label": "Activer la saisie de discussion via mpv",
    "chatdirectinput-label": "Autoriser la saisie de discussion instantanée (éviter d'avoir à appuyer sur la touche Entrée pour discuter)",
    "chatinputfont-label": "Police de caractères pour la saisie sur le Chat ",
    "chatfont-label": "Définir la fonte",
    "chatcolour-label": "Définir la couleur",
    "chatinputposition-label": "Position de la zone de saisie des messages dans mpv",
    "chat-top-option": "Haut",
    "chat-middle-option": "Milieu",
    "chat-bottom-option": "Bas",
    "chatoutputheader-label": "Sortie du message de discussion",
    "chatoutputfont-label": "Police de sortie du chat",
    "chatoutputenabled-label": "Activer la sortie du chat dans le lecteur multimédia (mpv uniquement pour l'instant)",
    "chatoutputposition-label": "Mode de sortie",
    "chat-chatroom-option": "Style de salon de discussion",
    "chat-scrolling-option": "Style de défilement",

    "mpv-key-tab-hint": "[TAB] pour basculer l'accès aux raccourcis des touches de la ligne alphabétique.",
    "mpv-key-hint": "[ENTER] pour envoyer un message. [ESC] pour quitter le mode chat.",
    "alphakey-mode-warning-first-line": "Vous pouvez temporairement utiliser les anciennes liaisons mpv avec les touches az.",
    "alphakey-mode-warning-second-line": "Appuyez sur [TAB] pour revenir au mode de discussion Syncplay.",

    "help-label": "Aider",
    "reset-label": "Réinitialiser",
    "run-label": "Exécuter Syncplay",
    "storeandrun-label": "Stocker la configuration et exécuter Syncplay",

    "contact-label": "Feel free to e-mail <a href=\"mailto:dev@syncplay.pl\"><nobr>dev@syncplay.pl</nobr></a>, <a href=\"https://github.com/Syncplay/syncplay/issues\"><nobr>create an issue</nobr></a> to report a bug/problem via GitHub, <a href=\"https://github.com/Syncplay/syncplay/discussions\"><nobr>start a discussion</nobr></a> to make a suggestion or ask a question via GitHub, <a href=\"https://www.facebook.com/SyncplaySoftware\"><nobr>like us on Facebook</nobr></a>, <a href=\"https://twitter.com/Syncplay/\"><nobr>follow us on Twitter</nobr></a>, or visit <a href=\"https://syncplay.pl/\"><nobr>https://syncplay.pl/</nobr></a>. Do not use Syncplay to send sensitive information.",

    "joinroom-label": "Rejoindre la salle",
    "joinroom-menu-label": "Rejoindre la salle {}",
    "seektime-menu-label": "Chercher le temps",
    "undoseek-menu-label": "Annuler la recherche",
    "play-menu-label": "Jouer",
    "pause-menu-label": "Pause",
    "playbackbuttons-menu-label": "Afficher les boutons de lecture",
    "autoplay-menu-label": "Afficher le bouton de lecture automatique",
    "autoplay-guipushbuttonlabel": "Jouer quand tout est prêt",
    "autoplay-minimum-label": "Utilisateurs minimum:",
    "hideemptyrooms-menu-label": "Hide empty persistent rooms", # TODO: Translate

    "sendmessage-label": "Envoyer",

    "ready-guipushbuttonlabel": "Je suis prêt à regarder !",

    "roomuser-heading-label": "Salon / Utilisateur",
    "size-heading-label": "Taille",
    "duration-heading-label": "Durée",
    "filename-heading-label": "Nom de fichier",
    "notifications-heading-label": "Notifications",
    "userlist-heading-label": "Liste de qui joue quoi",

    "browseformedia-label": "Parcourir les fichiers multimédias",

    "file-menu-label": "&Fichier",  # & precedes shortcut key
    "openmedia-menu-label": "&Ouvrir le fichier multimédia",
    "openstreamurl-menu-label": "Ouvrir l'URL du &flux multimédia",
    "setmediadirectories-menu-label": "Définir les &répertoires multimédias",
    "loadplaylistfromfile-menu-label": "&Charger la liste de lecture à partir du fichier",
    "saveplaylisttofile-menu-label": "&Enregistrer la liste de lecture dans un fichier",
    "exit-menu-label": "Sortir",
    "advanced-menu-label": "&Avancée",
    "window-menu-label": "&Fenêtre",
    "setoffset-menu-label": "Définir &décalage",
    "createcontrolledroom-menu-label": "&Créer une salon à gérer",
    "identifyascontroller-menu-label": "&Identifier en tant qu'opérateur de salon",
    "settrusteddomains-menu-label": "Définir des &domaines de confiance",
    "addtrusteddomain-menu-label": "Ajouter {} comme domaine de confiance",  # Domain

    "edit-menu-label": "&Éditer",
    "cut-menu-label": "Couper",
    "copy-menu-label": "&Copier",
    "paste-menu-label": "&Coller",
    "selectall-menu-label": "&Tout sélectionner",

    "playback-menu-label": "&Relecture",

    "help-menu-label": "&Aide",
    "userguide-menu-label": "Ouvrir le &guide de l'utilisateur",
    "update-menu-label": "Rechercher et mettre à jour",

    "startTLS-initiated": "Tentative de connexion sécurisée",
    "startTLS-secure-connection-ok": "Connexion sécurisée établie ({})",
    "startTLS-server-certificate-invalid": "Échec de la Connexion Sécurisée. Le serveur utilise un certificat de sécurité non valide. Cette communication pourrait être interceptée par un tiers. Pour plus de détails et de dépannage, voir <a href=\"https://syncplay.pl/trouble\">ici</a> .",
    "startTLS-server-certificate-invalid-DNS-ID": "Syncplay ne fait pas confiance à ce serveur car il utilise un certificat qui n'est pas valide pour son nom d'hôte.",
    "startTLS-not-supported-client": "Ce client ne prend pas en charge TLS",
    "startTLS-not-supported-server": "Ce serveur ne prend pas en charge TLS",

    # TLS certificate dialog
    "tls-information-title": "Détails du certificat",
    "tls-dialog-status-label": "<strong>Syncplay utilise une connexion cryptée à {}.</strong>",
    "tls-dialog-desc-label": "Le cryptage avec un certificat numérique préserve la confidentialité des informations lorsqu'elles sont envoyées vers ou depuis le serveur {}.",
    "tls-dialog-connection-label": "Informations chiffrées à l'aide de Transport Layer Security (TLS), version {} avec la suite de chiffrement: {}.",
    "tls-dialog-certificate-label": "Certificat délivré par {} valable jusqu'au {}.",

    # About dialog
    "about-menu-label": "&À propos de la lecture synchronisée",
    "about-dialog-title": "À propos de Syncplay",
    "about-dialog-release": "Version {} release {}",
    "about-dialog-license-text": "Sous licence Apache, version 2.0",
    "about-dialog-license-button": "Licence",
    "about-dialog-dependencies": "Dépendances",

    "setoffset-msgbox-label": "Définir le décalage",
    "offsetinfo-msgbox-label": "Offset (voir https://syncplay.pl/guide/ pour les instructions d'utilisation):",

    "promptforstreamurl-msgbox-label": "Ouvrir l'URL du flux multimédia",
    "promptforstreamurlinfo-msgbox-label": "URL de diffusion",

    "addfolder-label": "Ajouter le dossier",

    "adduris-msgbox-label": "Ajouter des URL à la liste de lecture (une par ligne)",
    "editplaylist-msgbox-label": "Définir la liste de lecture (une par ligne)",
    "trusteddomains-msgbox-label": "Domaines vers lesquels vous pouvez basculer automatiquement (un par ligne)",

    "createcontrolledroom-msgbox-label": "Créer un salon à  gérer",
    "controlledroominfo-msgbox-label": "Enter name of managed room\r\n(see https://syncplay.pl/guide/ for usage instructions):",

    "identifyascontroller-msgbox-label": "S'identifier en tant qu'opérateur de salon",
    "identifyinfo-msgbox-label": "Enter operator password for this room\r\n(see https://syncplay.pl/guide/ for usage instructions):",

    "public-server-msgbox-label": "Sélectionnez le serveur public pour cette session de visualisation",

    "megabyte-suffix": "Mo",

    # Tooltips

    "host-tooltip": "Nom d'hôte ou IP auquel se connecter, incluant éventuellement le port (par exemple syncplay.pl:8999). Uniquement synchronisé avec des personnes sur le même serveur/port.",
    "name-tooltip": "Surnom sous lequel vous serez connu. Pas d'inscription, donc peut facilement changer plus tard. Nom aléatoire généré si aucun n'est spécifié.",
    "password-tooltip": "Les mots de passe ne sont nécessaires que pour se connecter à des serveurs privés.",
    "room-tooltip": "Le salon à rejoindre lors de la connexion peut être presque n'importe quoi, mais vous ne serez synchronisé qu'avec des personnes dans le même salon.",

    "edit-rooms-tooltip": "Modifier la liste des salons.",

    "executable-path-tooltip": "Emplacement du lecteur multimédia pris en charge que vous avez choisi (mpv, mpv.net, VLC, MPC-HC/BE, mplayer2 ou IINA).",
    "media-path-tooltip": "Emplacement de la vidéo ou du flux à ouvrir. Nécessaire pour mplayer2.",
    "player-arguments-tooltip": "Arguments/commutateurs de ligne de commande supplémentaires à transmettre à ce lecteur multimédia.",
    "mediasearcdirectories-arguments-tooltip": "Répertoires dans lesquels Syncplay recherchera les fichiers multimédias, par exemple lorsque vous utilisez la fonctionalité cliquer pour basculer. Syncplay recherchera récursivement dans les sous-dossiers.",

    "more-tooltip": "Afficher les paramètres moins fréquemment utilisés.",
    "filename-privacy-tooltip": "Mode de confidentialité pour l'envoi du nom de fichier en cours de lecture au serveur.",
    "filesize-privacy-tooltip": "Mode de confidentialité pour l'envoi de la taille du fichier en cours de lecture au serveur.",
    "privacy-sendraw-tooltip": "Envoyez ces informations sans brouillage. Il s'agit de l'option par défaut avec la plupart des fonctionnalités.",
    "privacy-sendhashed-tooltip": "Envoyez une version hachée des informations, les rendant moins visibles pour les autres clients.",
    "privacy-dontsend-tooltip": "N'envoyez pas ces informations au serveur. Cela garantit une confidentialité maximale.",
    "checkforupdatesautomatically-tooltip": "Vérifiez régulièrement sur le site Web de Syncplay si une nouvelle version de Syncplay est disponible.",
    "autosavejoinstolist-tooltip": "Lorsque vous rejoignez un salon sur un serveur, mémorisez automatiquement le nom de la salle dans la liste des salons à rejoindre.",
    "slowondesync-tooltip": "Réduisez temporairement le taux de lecture si nécessaire pour vous synchroniser avec les autres téléspectateurs. Non pris en charge sur MPC-HC/BE.",
    "dontslowdownwithme-tooltip": "Cela signifie que les autres ne sont pas ralentis ou rembobinés si votre lecture est en retard. Utile pour les opérateurs de salon.",
    "pauseonleave-tooltip": "Mettez la lecture en pause si vous êtes déconnecté ou si quelqu'un quitte votre salon.",
    "readyatstart-tooltip": "Définissez-vous comme «prêt» au début (sinon, vous êtes défini comme «pas prêt» jusqu'à ce que vous changiez votre état de préparation)",
    "forceguiprompt-tooltip": "La boîte de dialogue de configuration ne s'affiche pas lors de l'ouverture d'un fichier avec Syncplay.",  # (Inverted)
    "nostore-tooltip": "Exécutez Syncplay avec la configuration donnée, mais ne stockez pas les modifications de manière permanente.",  # (Inverted)
    "rewindondesync-tooltip": "Revenez en arrière au besoin pour vous synchroniser. La désactivation de cette option peut entraîner des désynchronisations majeures!",
    "fastforwardondesync-tooltip": "Avancez en cas de désynchronisation avec l'opérateur de la salle (ou votre position factice si l'option «Ne jamais ralentir ou rembobiner les autres» est activée).",
    "showosd-tooltip": "Envoie des messages Syncplay à l'OSD du lecteur multimédia.",
    "showosdwarnings-tooltip": "Afficher des avertissements en cas de lecture d'un fichier différent, seul dans la pièce, utilisateurs non prêts, etc.",
    "showsameroomosd-tooltip": "Afficher les notifications OSD pour les événements liés à l'utilisateur du salon.",
    "shownoncontrollerosd-tooltip": "Afficher les notifications OSD pour les événements relatifs aux non-opérateurs qui se trouvent dans les salles gérées.",
    "showdifferentroomosd-tooltip": "Afficher les notifications OSD pour les événements liés à l'absence de l'utilisateur du salon.",
    "showslowdownosd-tooltip": "Afficher les notifications de ralentissement / de retour au décalage temps.",
    "showdurationnotification-tooltip": "Utile lorsqu'un segment dans un fichier en plusieurs parties est manquant, mais peut entraîner des faux positifs.",
    "language-tooltip": "Langue à utiliser par Syncplay.",
    "unpause-always-tooltip": "Si vous appuyez sur unpause, cela vous définit toujours comme prêt et non-pause, plutôt que de simplement vous définir comme prêt.",
    "unpause-ifalreadyready-tooltip": "Si vous appuyez sur unpause lorsque vous n'êtes pas prêt, cela vous mettra comme prêt - appuyez à nouveau sur unpause pour reprendre la pause.",
    "unpause-ifothersready-tooltip": "Si vous appuyez sur unpause lorsque vous n'êtes pas prêt, il ne reprendra la pause que si d'autres sont prêts.",
    "unpause-ifminusersready-tooltip": "Si vous appuyez sur annuler la pause lorsqu'il n'est pas prêt, il ne s'arrêtera que si d'autres personnes sont prêtes et que le seuil minimal d'utilisateurs est atteint.",
    "trusteddomains-arguments-tooltip": "Domaines vers lesquels Syncplay peut basculer automatiquement lorsque les listes de lecture partagées sont activées.",

    "chatinputenabled-tooltip": "Activer la saisie du chat dans mpv (appuyez sur Entrée pour discuter, Entrée pour envoyer, Échap pour annuler)",
    "chatdirectinput-tooltip": "Évitez d'avoir à appuyer sur «enter» pour passer en mode de saisie de discussion dans mpv. Appuyez sur TAB dans mpv pour désactiver temporairement cette fonctionnalité.",
    "font-label-tooltip": "Police utilisée lors de la saisie de messages de discussion dans mpv. Côté client uniquement, n'affecte donc pas ce que les autres voient.",
    "set-input-font-tooltip": "Famille de polices utilisée lors de la saisie de messages de discussion dans mpv. Côté client uniquement, n'affecte donc pas ce que les autres voient.",
    "set-input-colour-tooltip": "Couleur de police utilisée lors de la saisie de messages de discussion dans mpv. Côté client uniquement, n'affecte donc pas ce que les autres voient.",
    "chatinputposition-tooltip": "Emplacement dans mpv où le texte d'entrée de discussion apparaîtra lorsque vous appuyez sur Entrée et tapez.",
    "chatinputposition-top-tooltip": "Placez l'entrée de discussion en haut de la fenêtre mpv.",
    "chatinputposition-middle-tooltip": "Placez l'entrée de discussion au point mort de la fenêtre mpv.",
    "chatinputposition-bottom-tooltip": "Placez l'entrée de discussion en bas de la fenêtre mpv.",
    "chatoutputenabled-tooltip": "Afficher les messages de discussion dans l'OSD (si pris en charge par le lecteur multimédia).",
    "font-output-label-tooltip": "Police de sortie du chat.",
    "set-output-font-tooltip": "Police utilisée pour l'affichage des messages de discussion.",
    "chatoutputmode-tooltip": "Comment les messages de chat sont affichés.",
    "chatoutputmode-chatroom-tooltip": "Affichez les nouvelles lignes de discussion directement sous la ligne précédente.",
    "chatoutputmode-scrolling-tooltip": "Faites défiler le texte du chat de droite à gauche.",

    "help-tooltip": "Ouvre le guide de l'utilisateur de Syncplay.pl.",
    "reset-tooltip": "Réinitialisez tous les paramètres à la configuration par défaut.",
    "update-server-list-tooltip": "Connectez-vous à syncplay.pl pour mettre à jour la liste des serveurs publics.",

    "sslconnection-tooltip": "Connecté en toute sécurité au serveur. Cliquez pour obtenir les détails du certificat.",

    "joinroom-tooltip": "Quitter la salle actuelle et rejoindre le salon spécifié.",
    "seektime-msgbox-label": "Aller au temps spécifié (en secondes / min:sec). Utilisez +/- pour la recherche relative.",
    "ready-tooltip": "Indique si vous êtes prêt à regarder.",
    "autoplay-tooltip": "Lecture automatique lorsque tous les utilisateurs qui ont un indicateur de disponibilité sont prêts et que le seuil d'utilisateur minimum est atteint.",
    "switch-to-file-tooltip": "Double-cliquez pour passer à {}",  # Filename
    "sendmessage-tooltip": "Envoyer un message au salon",

    # In-userlist notes (GUI)
    "differentsize-note": "Différentes tailles!",
    "differentsizeandduration-note": "Taille et durée différentes !",
    "differentduration-note": "Durée différente !",
    "nofile-note": "(Aucun fichier en cours de lecture)",

    # Server messages to client
    "new-syncplay-available-motd-message": "Vous utilisez Syncplay {} mais une version plus récente est disponible sur https://syncplay.pl",  # ClientVersion
    "persistent-rooms-notice": "NOTICE: This server uses persistent rooms, which means that the playlist information is stored between playback sessions. If you want to create a room where information is not saved then put -temp at the end of the room name.", # NOTE: Do not translate the word -temp # TODO: Translate
    "ready-chat-message": "I have set {} as ready.",  # User # TODO: Translate
    "not-ready-chat-message": "I have set {} as not ready.",  # User # TODO: Translate

    # Server notifications
    "welcome-server-notification": "Bienvenue sur le serveur Syncplay, ver.",  # version
    "client-connected-room-server-notification": "({2}) connecté à la salle '{1}'",  # username, host, room
    "client-left-server-notification": "a quitté le serveur",  # name
    "no-salt-notification": "VEUILLEZ NOTER: Pour permettre aux mots de passe d'opérateur de salle générés par cette instance de serveur de fonctionner lorsque le serveur est redémarré, veuillez ajouter l'argument de ligne de commande suivant lors de l'exécution du serveur Syncplay à l'avenir: --salt {}",  # Salt


    # Server arguments
    "server-argument-description": "Solution pour synchroniser la lecture de plusieurs instances de lecteur multimédia sur le réseau. Instance de serveur",
    "server-argument-epilog": "Si aucune option n'est fournie, les valeurs _config seront utilisées",
    "server-port-argument": "port TCP du serveur",
    "server-password-argument": "Mot de passe du serveur",
    "server-isolate-room-argument": "faut-il isoler les salons ?",
    "server-salt-argument": "chaîne aléatoire utilisée pour générer les mots de passe des salons gérés",
    "server-disable-ready-argument": "désactiver la fonction de préparation",
    "server-motd-argument": "chemin vers le fichier à partir duquel motd sera récupéré",
    "server-rooms-argument": "path to database file to use and/or create to store persistent room data. Enables rooms to persist without watchers and through restarts", # TODO: Translate
    "server-permanent-rooms-argument": "path to file which lists permenant rooms that will be listed even if the room is empty (in the form of a text file which lists one room per line) - requires persistent rooms to be enabled", # TODO: Translate
    "server-chat-argument": "Le chat doit-il être désactivé?",
    "server-chat-maxchars-argument": "Nombre maximum de caractères dans un message de discussion (la valeur par défaut est {})", # Default number of characters
    "server-maxusernamelength-argument": "Nombre maximum de caractères dans un nom d'utilisateur (la valeur par défaut est {})",
    "server-stats-db-file-argument": "Activer les statistiques du serveur à l'aide du fichier db SQLite fourni",
    "server-startTLS-argument": "Activer les connexions TLS à l'aide des fichiers de certificat dans le chemin fourni",
    "server-messed-up-motd-unescaped-placeholders": "Le message du jour a des espaces réservés non échappés. Tous les signes $ doivent être doublés ($$).",
    "server-messed-up-motd-too-long": "Le message du jour est trop long: {}caractères maximum, {} donnés.",
    "server-listen-only-on-ipv4": "Listen only on IPv4 when starting the server.",
    "server-listen-only-on-ipv6": "Listen only on IPv6 when starting the server.",
    "server-interface-ipv4": "The IP address to bind to for IPv4. Leaving it empty defaults to using all.",
    "server-interface-ipv6": "The IP address to bind to for IPv6. Leaving it empty defaults to using all.",

    # Server errors
    "unknown-command-server-error": "Commande inconnue {}",  # message
    "not-json-server-error": "Pas une chaîne encodée json {}",  # message
    "line-decode-server-error": "Pas une chaîne utf-8",
    "not-known-server-error": "Vous devez être connu du serveur avant d'envoyer cette commande",
    "client-drop-server-error": "Client drop: {} -- {}",  # host, error
    "password-required-server-error": "Mot de passe requis",
    "wrong-password-server-error": "Mauvais mot de passe fourni",
    "hello-server-error": "Pas assez d'arguments pour Hello",  # DO NOT TRANSLATE

    # Playlists
    "playlist-selection-changed-notification": "{} a modifié la sélection de la liste de lecture",  # Username
    "playlist-contents-changed-notification": "{} a mis à jour la liste de lecture",  # Username
    "cannot-find-file-for-playlist-switch-error": "Impossible de trouver le fichier {} dans les répertoires multimédias pour le changement de liste de lecture!",  # Filename
    "cannot-add-duplicate-error": "Impossible d'ajouter la deuxième entrée pour '{}' à la liste de lecture car aucun doublon n'est autorisé.",  # Filename
    "cannot-add-unsafe-path-error": "Impossible de charger automatiquement {}, car il ne se trouve pas sur un domaine approuvé. Vous pouvez basculer manuellement vers l'URL en double-cliquant dessus dans la liste de lecture et ajouter des domaines de confiance via Fichier->Avancé->Définir les domaines de confiance. Si vous faites un clic droit sur une URL, vous pouvez ajouter son domaine en tant que domaine de confiance via le menu contextuel.",  # Filename
    "sharedplaylistenabled-label": "Activer les listes de lecture partagées",
    "removefromplaylist-menu-label": "Supprimer de la liste de lecture",
    "shuffleremainingplaylist-menu-label": "Mélanger la liste de lecture restante",
    "shuffleentireplaylist-menu-label": "Mélanger toute la liste de lecture",
    "undoplaylist-menu-label": "Annuler la dernière modification de la liste de lecture",
    "addfilestoplaylist-menu-label": "Ajouter des fichiers au bas de la liste de lecture",
    "addurlstoplaylist-menu-label": "Ajouter des URL au bas de la liste de lecture",
    "editplaylist-menu-label": "Modifier la liste de lecture",

    "open-containing-folder": "Ouvrir le dossier contenant ce fichier",
    "addyourfiletoplaylist-menu-label": "Ajoutez votre fichier à la liste de lecture",
    "addotherusersfiletoplaylist-menu-label": "Ajouter le fichier de {} à la liste de lecture",  # [Username]
    "addyourstreamstoplaylist-menu-label": "Ajoutez votre flux à la liste de lecture",
    "addotherusersstreamstoplaylist-menu-label": "Ajouter {}' stream à la playlist",  # [Username]
    "openusersstream-menu-label": "Ouvrir le flux de {}",  # [username]'s
    "openusersfile-menu-label": "Ouvrir le fichier de {}",  # [username]'s

    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate

    "playlist-instruction-item-message": "Faites glisser le fichier ici pour l'ajouter à la liste de lecture partagée.",
    "sharedplaylistenabled-tooltip": "Les opérateurs de salle peuvent ajouter des fichiers à une liste de lecture synchronisée pour permettre à tout le monde de regarder facilement la même chose. Configurez les répertoires multimédias sous «Divers».",

    "playlist-empty-error": "La liste de lecture est actuellement vide.",
    "playlist-invalid-index-error": "Index de liste de lecture non valide",
}



# coding:utf8

"""Spanish dictionary"""

# Filename, dictionary name and LANGUAGE-TAG value based on ISO country code. Language tag listed at https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/a9eac961-e77d-41a6-90a5-ce1a8b0cdb9c?redirectedfrom=MSDN

es = {
    "LANGUAGE": "Español",
    "LANGUAGE-TAG": "es",

    # Strings for Windows NSIS installer
    "installer-language-file": "Spanish.nlf", # Relevant .nlf file at https://github.com/kichik/nsis/tree/master/Contrib/Language%20files
    "installer-associate": "Asociar Syncplay con archivos multimedia.",
    "installer-shortcut": "Crear accesos directos en las siguientes ubicaciones:",
    "installer-start-menu": "Menú de inicio",
    "installer-desktop": "Escritorio",
    "installer-quick-launch-bar": "Barra de acceso rápido",
    "installer-automatic-updates": "Buscar actualizaciones automáticamente",
    "installer-uninstall-configuration": "Borrar archivo de configuración.",

    # Client notifications
    "config-cleared-notification": "Ajustes limpiados. Los cambios serán guardados cuando almacenes una configuración válida.",

    "relative-config-notification": "Cargados los archivo(s) de configuración relativa: {}",

    "connection-attempt-notification": "Intentando conectarse a {}:{}",  # Port, IP
    "reconnection-attempt-notification": "Se perdió la conexión con el servidor, intentando reconectar",
    "disconnection-notification": "Desconectado del servidor",
    "connection-failed-notification": "La conexión con el servidor falló",
    "connected-successful-notification": "Conectado al servidor exitosamente",
    "retrying-notification": "%s, Reintentando en %d segundos...",  # Seconds
    "reachout-successful-notification": "Se alcanzó {} ({}) satisfactoriamente",

    "rewind-notification": "Rebobinado debido a diferencia de tiempo con {}",  # User
    "fastforward-notification": "Adelantado debido a diferencia de tiempo con {}",  # User
    "slowdown-notification": "Ralentizando debido a diferencia de tiempo con {}",  # User
    "revert-notification": "Revirtiendo a la velocidad normal",

    "pause-notification": "{} pausado ({})", # User, Time - TODO: Change into format "{} paused at {}" in line with English message
    "unpause-notification": "{} resumido",  # User
    "seek-notification": "{} saltó desde {} hasta {}",  # User, from time, to time

    "current-offset-notification": "Compensación actual: {} segundos",  # Offset

    "media-directory-list-updated-notification": "Se han actualizado los directorios multimedia de Syncplay.",

    "room-join-notification": "{} se unió al canal: '{}'",  # User
    "left-notification": "{} se fue",  # User
    "left-paused-notification": "{} se fue, {} pausó",  # User who left, User who paused
    "playing-notification": "{} está reproduciendo '{}' ({})",  # User, file, duration
    "playing-notification/room-addendum":  " en la sala: '{}'",  # Room

    "not-all-ready": "No están listos: {}",  # Usernames
    "all-users-ready": "Todos están listos ({} users)",  # Number of ready users
    "ready-to-unpause-notification": "Se te ha establecido como listo - despausa nuevamente para resumir",
    "set-as-ready-notification": "Se te ha establecido como listo",
    "set-as-not-ready-notification": "Se te ha establecido como no-listo",
    "autoplaying-notification": "Reproduciendo automáticamente en {}...",  # Number of seconds until playback will start

    "identifying-as-controller-notification": "Autentificando como el operador de la sala, con contraseña '{}'...",
    "failed-to-identify-as-controller-notification": "{} falló la autentificación como operador de la sala.",
    "authenticated-as-controller-notification": "{} autentificado como operador de la sala",
    "created-controlled-room-notification": "Sala administrada '{}' creada con contraseña '{}'. Por favor guarda esta información para referencias futuras!\n\nIn managed rooms everyone is kept in sync with the room operator(s) who are the only ones who can pause, unpause, seek, and change the playlist.\n\nYou should ask regular viewers to join the room '{}' but the room operators can join the room '{}' to automatically authenticate themselves.", # RoomName, operatorPassword, roomName, roomName:operatorPassword # TODO: Translate

    "other-set-as-ready-notification": "{} was set as ready by {}", # User set as ready, user who set them as ready # TODO: Translate
    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate

    "file-different-notification": "El archivo que reproduces parece ser diferente al archivo de {}",  # User
    "file-differences-notification": "Tu archivo difiere de la(s) siguiente(s) forma(s): {}",  # Differences
    "room-file-differences": "Diferencias de archivo: {}",  # File differences (filename, size, and/or duration)
    "file-difference-filename": "nombre",
    "file-difference-filesize": "tamaño",
    "file-difference-duration": "duración",
    "alone-in-the-room": "Estás solo en la sala",

    "different-filesize-notification": " (el tamaño de su archivo difiere con el tuyo!)",
    "userlist-playing-notification": "{} está reproduciendo:",  # Username
    "file-played-by-notification": "Archivo: {} está siendo reproducido por:",  # File
    "no-file-played-notification": "{} está ahora reproduciendo un archivo",  # Username
    "notplaying-notification": "Personas que no reproducen algún archivo:",
    "userlist-room-notification":  "En sala '{}':",  # Room
    "userlist-file-notification": "Archivo",
    "controller-userlist-userflag": "Operador",
    "ready-userlist-userflag": "Listo",

    "update-check-failed-notification": "No se pudo determinar automáticamente que Syncplay {} esté actualizado. ¿Te gustaría visitar https://syncplay.pl/ para buscar actualizaciones manualmente?",  # Syncplay version
    "syncplay-uptodate-notification": "Syncplay está actualizado",
    "syncplay-updateavailable-notification": "Una nueva versión de Syncplay está disponible. ¿Te gustaría visitar la página del lanzamiento?",

    "mplayer-file-required-notification": "Al utilizar Syncplay con mplayer se debe proveer un archivo al inicio.",
    "mplayer-file-required-notification/example": "Ejemplo de uso: syncplay [opciones] [url|ubicación/]nombreDelArchivo",
    "mplayer2-required": "Syncplay no es compatible con MPlayer 1.x, por favor utiliza mplayer2 o mpv",

    "unrecognized-command-notification": "Comando no reconocido",
    "commandlist-notification": "Comandos disponibles:",
    "commandlist-notification/room": "\tr [nombre] - cambiar de sala",
    "commandlist-notification/list": "\tl - mostrar lista de usuarios",
    "commandlist-notification/undo": "\tu - deshacer última búsqueda",
    "commandlist-notification/pause": "\tp - activar pausa",
    "commandlist-notification/seek": "\t[s][+-]tiempo - ir al tiempo definido, si no se especifica + o -, será el tiempo absoluto en segundos o min:sec",
    "commandlist-notification/offset": "\to[+-]duration - offset local playback by the given duration (in seconds or min:sec) from the server seek position - this is a deprecated feature", # TODO: Translate
    "commandlist-notification/help": "\th - esta ayuda",
    "commandlist-notification/toggle": "\tt - activa/inactiva señal que estás listo para ver",
    "commandlist-notification/setready": "\tsr [name] - sets user as ready",  # TODO: Translate
    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready",  # TODO: Translate
    "commandlist-notification/create": "\tc [nombre] - crear sala administrada usando el nombre de la sala actual",
    "commandlist-notification/auth": "\ta [contraseña] - autentificar como operador de la sala con la contraseña de operador",
    "commandlist-notification/chat": "\tch [mensaje] - enviar un mensaje en la sala",
    "commandList-notification/queue": "\tqa [file/url] - add file or url to bottom of playlist",  # TO DO: Translate
    "commandList-notification/queueandselect": "\tqas [file/url] - add file or url to bottom of playlist and select it",  # TO DO: Translate
    "commandList-notification/playlist": "\tql - show the current playlist",  # TO DO: Translate
    "commandList-notification/select": "\tqs [index] - select given entry in the playlist",  # TO DO: Translate
    "commandList-notification/next": "\tqn - select next entry in the playlist", # TODO: Translate
    "commandList-notification/delete": "\tqd [index] - delete the given entry from the playlist",  # TO DO: Translate
    "syncplay-version-notification": "Versión de Syncplay: {}",  # syncplay.version
    "more-info-notification": "Más información disponible en: {}",  # projectURL

    "gui-data-cleared-notification": "Syncplay limpió la ruta y el estado de la ventana utilizado por la GUI.",
    "language-changed-msgbox-label": "El lenguaje se modificará cuando ejecutes Syncplay.",
    "promptforupdate-label": "¿Está bien si Syncplay comprueba por actualizaciones automáticamente y de vez en cuando?",

    "media-player-latency-warning": "Advertencia: El reproductor multimedia tardó {} segundos en responder. Si experimentas problemas de sincronización, cierra otros programas para liberar recursos del sistema; si esto no funciona, intenta con otro reproductor multimedia.",  # Seconds to respond
    "mpv-unresponsive-error": "mpv no ha respondido por {} segundos. Al aparecer no está funcionando correctamente. Por favor reinicia Syncplay.",  # Seconds to respond

    # Client prompts
    "enter-to-exit-prompt": "Presiona intro para salir\n",

    # Client errors
    "missing-arguments-error": "Están faltando algunos argumentos necesarios. Por favor revisa --help",
    "server-timeout-error": "La conexión con el servidor ha caducado",
    "mpc-slave-error": "No se logró iniciar MPC en modo esclavo!",
    "mpc-version-insufficient-error": "La versión de MPC no es suficiente, por favor utiliza `mpc-hc` >= `{}`",
    "mpc-be-version-insufficient-error": "La versión de MPC no es suficiente, por favor utiliza `mpc-be` >= `{}`",
    "mpv-version-error": "Syncplay no es compatible con esta versión de mpv. Por favor utiliza una versión diferente de mpv (p.ej. Git HEAD).",
    "mpv-failed-advice": "The reason mpv cannot start may be due to the use of unsupported command line arguments or an unsupported version of mpv.", # TODO: Translate
    "player-file-open-error": "El reproductor falló al abrir el archivo",
    "player-path-error": "La ruta del reproductor no está definida correctamente. Los reproductores soportados son: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2, y IINA",
    "hostname-empty-error": "El nombre del host no puede ser vacío",
    "empty-error": "{} no puede ser vacío",  # Configuration
    "media-player-error": "Error del reproductor multimedia: \"{}\"",  # Error line
    "unable-import-gui-error": "No se lograron importar las librerías GUI. Si no tienes instalado PySide, entonces tendrás que instalarlo para que funcione el GUI. If you want to run Syncplay in console mode then run it with the --no-gui command line switch. See https://syncplay.pl/guide/ for more details.", # TODO: Translate end of message and update second sentence to be a translation of "You need to have the correct version of PySide installed for the GUI to work."
    "unable-import-twisted-error": "No se logró importar Twisted. Por favor instala Twisted v16.4.0 o posterior.",

    "arguments-missing-error": "Están faltando algunos argumentos necesarios. Por favor revisa --help",

    "unable-to-start-client-error": "No se logró iniciar el cliente",

    "player-path-config-error": "La ruta del reproductor no está definida correctamente. Los reproductores soportados son: mpv, mpv.net, VLC, MPC-HC, MPC-BE, mplayer2 y IINA.",
    "no-file-path-config-error": "El archivo debe ser seleccionado antes de iniciar el reproductor",
    "no-hostname-config-error": "El nombre del host no puede ser vacío",
    "invalid-port-config-error": "El puerto debe ser válido",
    "empty-value-config-error": "{} no puede ser vacío",  # Config option

    "not-json-error": "No es una cadena de caracteres JSON válida\n",
    "hello-arguments-error": "Not enough Hello arguments\n",  # DO NOT TRANSLATE
    "version-mismatch-error": "No coinciden las versiones del cliente y servidor\n",
    "vlc-failed-connection": "Falló la conexión con VLC. Si no has instalado syncplay.lua y estás usando la última versión de VLC, por favor revisa https://syncplay.pl/LUA/ para obtener instrucciones. Syncplay and VLC 4 are not currently compatible, so either use VLC 3 or an alternative such as mpv.", # TO DO: TRANSLATE
    "vlc-failed-noscript": "VLC ha reportado que la interfaz syncplay.lua no se ha instalado. Por favor revisa https://syncplay.pl/LUA/ para obtener instrucciones.",
    "vlc-failed-versioncheck": "Esta versión de VLC no está soportada por Syncplay.",
    "vlc-initial-warning": 'VLC does not always provide accurate position information to Syncplay, especially for .mp4 and .avi files. If you experience problems with erroneous seeking then please try an alternative media player such as <a href="https://mpv.io/">mpv</a> (or <a href="https://github.com/stax76/mpv.net/">mpv.net</a> for Windows users).', # TODO: Translatef

    "feature-sharedPlaylists": "listas de reproducción compartidas",  # used for not-supported-by-server-error
    "feature-chat": "chat",  # used for not-supported-by-server-error
    "feature-readiness": "preparación",  # used for not-supported-by-server-error
    "feature-managedRooms": "salas administradas",  # used for not-supported-by-server-error
    "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate

    "not-supported-by-server-error": "La característica {} no está soportada por este servidor..",  # feature
    "shared-playlists-not-supported-by-server-error": "El servidor no admite la función de listas de reproducción compartidas. Para asegurarse de que funciona correctamente, se requiere un servidor que ejecute Syncplay {}+, pero el servidor está ejecutando Syncplay {}.",  # minVersion, serverVersion
    "shared-playlists-disabled-by-server-error": "La función de lista de reproducción compartida no está habilitada en la configuración del servidor. Para utilizar esta función, debes conectarte a un servidor distinto.",

    "invalid-seek-value": "Valor de búsqueda inválido",
    "invalid-offset-value": "Valor de desplazamiento inválido",

    "switch-file-not-found-error": "No se pudo cambiar el archivo '{0}'. Syncplay busca en los directorios de medios especificados.",  # File not found
    "folder-search-timeout-error": "Se anuló la búsqueda de medios en el directorio de medios, ya que tardó demasiado buscando en '{}' (after having processed the first {:,} files). Esto ocurrirá si seleccionas una carpeta con demasiadas subcarpetas en tu lista de carpetas de medios para buscar. Para que el cambio automático de archivos vuelva a funcionar, selecciona Archivo->Establecer directorios de medios en la barra de menú y elimina este directorio o reemplázalo con una subcarpeta apropiada. Si la carpeta está bien, puedes volver a reactivarlo seleccionando Archivo->Establecer directorios de medios y presionando 'OK'.", # Folder, Files processed - Note: {:,} is {} but with added commas seprators - TODO: Translate
    "folder-search-timeout-warning": "Warning: It has taken {} seconds to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
    "folder-search-first-file-timeout-error": "Se anuló la búsqueda de medios en '{}', ya que tardó demasiado buscando en acceder al directorio. Esto podría ocurrir si se trata de una unidad de red, o si tienes configurada la unidad para centrifugar luego de cierto período de inactividad. Para que el cambio automático de archivos vuelva a funcionar, por favor dirígete a Archivo->Establecer directorios de medios y elimina el directorio o resuelve el problema (p.ej. cambiando la configuración de ahorro de energía).",  # Folder
    "added-file-not-in-media-directory-error": "Has cargado un archivo en '{}' el cual no es un directorio de medios conocido. Puedes agregarlo como un directorio de medios seleccionado Archivo->Establecer directorios de medios en la barra de menú.",  # Folder
    "no-media-directories-error": "No se han establecido directorios de medios. Para que las funciones de lista de reproducción compartida y cambio de archivos funcionen correctamente, selecciona Archivo->Establecer directorios de medios y especifica dónde debe buscar Syncplay para encontrar archivos multimedia.",
    "cannot-find-directory-error": "No se encontró el directorio de medios '{}'.Para actualizar tu lista de directorios de medios, seleccciona Archivo->Establecer directorios de medios desde la barra de menú y especifica dónde debe buscar Syncplay para encontrar archivos multimedia.",

    "failed-to-load-server-list-error": "Error al cargar la lista de servidor públicos. Por favor visita https://www.syncplay.pl/ en tu navegador.",

    # Client arguments
    "argument-description": 'Solución para sincronizar la reproducción de múltiples instancias de reproductores de medios, a través de la red.',
    "argument-epilog": 'Si no se especifican opciones, se utilizarán los valores de _config',
    "nogui-argument": 'no mostrar GUI',
    "host-argument": 'dirección del servidor',
    "name-argument": 'nombre de usuario deseado',
    "debug-argument": 'modo debug',
    "force-gui-prompt-argument": 'hacer que aparezca el aviso de configuración',
    "no-store-argument": 'no guardar valores en .syncplay',
    "room-argument": 'sala por defecto',
    "password-argument": 'contraseña del servidor',
    "player-path-argument": 'ruta al ejecutable de tu reproductor',
    "file-argument": 'archivo a reproducir',
    "args-argument": 'opciones del reproductor, si necesitas pasar opciones que empiezan con -, pásalas utilizando \'--\'',
    "clear-gui-data-argument": 'restablece ruta y los datos del estado de la ventana GUI almacenados como QSettings',
    "language-argument": 'lenguaje para los mensajes de Syncplay ({})', # Languages

    "version-argument": 'imprime tu versión',
    "version-message": "Estás usando la versión de Syncplay {} ({})",

    "load-playlist-from-file-argument": "loads playlist from text file (one entry per line)", # TODO: Translate

    # Client labels
    "config-window-title": "Configuración de Syncplay",

    "connection-group-title": "Configuración de conexión",
    "host-label": "Dirección del servidor: ",
    "name-label":  "Nombre de usuario (opcional):",
    "password-label":  "Contraseña del servidor (si corresponde):",
    "room-label": "Sala por defecto: ",
    "roomlist-msgbox-label": "Edit room list (one per line)", # TODO: Translate

    "media-setting-title": "Configuración del reproductor multimedia",
    "executable-path-label": "Ruta al reproductor multimedia:",
    "media-path-label": "Ruta al video (opcional):",
    "player-arguments-label": "Argumentos del reproductor (si corresponde):",
    "browse-label": "Visualizar",
    "update-server-list-label": "Actualizar lista",

    "more-title": "Mostrar más configuraciones",
    "never-rewind-value": "Nunca",
    "seconds-suffix": " segs",
    "privacy-sendraw-option": "Enviar crudo",
    "privacy-sendhashed-option": "Enviar \"hasheado\"",
    "privacy-dontsend-option": "No enviar",
    "filename-privacy-label": "Información del nombre de archivo:",
    "filesize-privacy-label": "Información del tamaño de archivo:",
    "checkforupdatesautomatically-label": "Buscar actualizaciones de Syncplay automáticamente",
    "autosavejoinstolist-label": "Add rooms you join to the room list", # TO DO: Translate
    "slowondesync-label": "Ralentizar si hay una desincronización menor (no soportado en MPC-HC/BE)",
    "rewindondesync-label": "Rebobinar si hay una desincronización mayor (recomendado)",
    "fastforwardondesync-label": "Avanzar rápidamente si hay un retraso (recomendado)",
    "dontslowdownwithme-label": "Nunca ralentizar ni rebobinar a otros (experimental)",
    "pausing-title": "Pausando",
    "pauseonleave-label": "Pausar cuando un usuario se va (p.ej. si se desconectan)",
    "readiness-title": "Estado de preparación inicial",
    "readyatstart-label": "Establecerme como \"listo-para-ver\" por defecto",
    "forceguiprompt-label": "No mostrar siempre la ventana de configuración de Syncplay",  # (Inverted)
    "showosd-label": "Activar mensajes OSD",

    "showosdwarnings-label": "Incluir advertencias (p.ej. cuando los archivos son distintos, los usuarios no están listos)",
    "showsameroomosd-label": "Incluir eventos en tu sala",
    "shownoncontrollerosd-label": "Incluir eventos de no-operadores en salas administradas",
    "showdifferentroomosd-label": "Incluir eventos en otras salas",
    "showslowdownosd-label": "Incluir notificaciones de ralentización/reversión",
    "language-label": "Lenguaje:",
    "automatic-language": "Predeterminado ({})",  # Default language
    "showdurationnotification-label": "Advertir sobre discrepancias en la duración de los medios",
    "basics-label": "Básicos",
    "readiness-label": "Reproducir/Pausar",
    "misc-label": "Misc.",
    "core-behaviour-title": "Comportamiento de la sala central",
    "syncplay-internals-title": "Internos de Syncplay",
    "syncplay-mediasearchdirectories-title": "Directorios para buscar medios",
    "syncplay-mediasearchdirectories-label": "Directorios para buscar medios (una ruta por línea)",
    "sync-label": "Sincronizar",
    "sync-otherslagging-title": "Si otros se están quedando atrás...",
    "sync-youlaggging-title": "Si tú te estás quedando atrás...",
    "messages-label": "Mensajes",
    "messages-osd-title": "Configuraciones de visualización en pantalla",
    "messages-other-title": "Otras configuraciones de visualización",
    "chat-label": "Chat",
    "privacy-label": "Privacidad",  # Currently unused, but will be brought back if more space is needed in Misc tab
    "privacy-title": "Configuración de privacidad",
    "unpause-title": "Si presionas reproducir, definir como listo y:",
    "unpause-ifalreadyready-option": "Despausar si ya está definido como listo",
    "unpause-ifothersready-option": "Despausar si ya está listo u otros en la sala están listos (predeterminado)",
    "unpause-ifminusersready-option": "Despausar si ya está listo, o si todos los demás están listos y el mín. de usuarios están listos",
    "unpause-always": "Siempre despausar",
    "syncplay-trusteddomains-title": "Dominios de confianza (para servicios de transmisión y contenido alojado)",

    "chat-title": "Entrada de mensaje de chat",
    "chatinputenabled-label": "Habilitar entrada de chat a través de mpv",
    "chatdirectinput-label": "Permitir entrada de chat instantánea (omitir tener que presionar Intro para chatear)",
    "chatinputfont-label": "Fuente de entrada de chat",
    "chatfont-label": "Establecer fuente",
    "chatcolour-label": "Establecer color",
    "chatinputposition-label": "Posición del área de entrada del mensaje en mpv",
    "chat-top-option": "Arriba",
    "chat-middle-option": "Medio",
    "chat-bottom-option": "Fondo",
    "chatoutputheader-label": "Salida de mensaje de chat",
    "chatoutputfont-label": "Fuente de salida de chat",
    "chatoutputenabled-label": "Habilitar salida de chat en el reproductor (solo mpv por ahora)",
    "chatoutputposition-label": "Modo de salida",
    "chat-chatroom-option": "Estilo de sala de chat",
    "chat-scrolling-option": "Estilo de desplazamiento",

    "mpv-key-tab-hint": "[TAB] para alternar acceso a los accesos directos de las teclas de la fila del alfabeto",
    "mpv-key-hint": "[INTRO] para enviar mensaje. [ESC] para salir del modo de chat.",
    "alphakey-mode-warning-first-line": "Puedes usar temporalmente los enlaces de mpv con las teclas a-z.",
    "alphakey-mode-warning-second-line": "Presiona [TAB] para retornar al modo de chat de Syncplay.",

    "help-label": "Ayuda",
    "reset-label": "Restaurar valores predeterminados",
    "run-label": "Ejecutar Syncplay",
    "storeandrun-label": "Almacenar la configuración y ejecutar Syncplay",

    "contact-label": "No dudes en enviar un correo electrónico a <a href=\"mailto:dev@syncplay.pl\"><nobr>dev@syncplay.pl</nobr></a>, <a href=\"https://github.com/Syncplay/syncplay/issues\"><nobr>reportar un problema</nobr></a> vía GitHub / <a href=\"https://github.com/Syncplay/syncplay/discussions\"><nobr>start a discussion</nobr></a> to make a suggestion or ask a question via GitHub, <a href=\"https://www.facebook.com/SyncplaySoftware\"><nobr>danos \"me gusta\" en Facebook</nobr></a>, <a href=\"https://twitter.com/Syncplay/\"><nobr>síguenos en Twitter</nobr></a>, o visita <a href=\"https://syncplay.pl/\"><nobr>https://syncplay.pl/</nobr></a>. No utilices Syncplay para enviar información sensible.", # TODO: Update translation

    "joinroom-label": "Unirse a la sala",
    "joinroom-menu-label": "Unirse a la sala {}",
    "seektime-menu-label": "Buscar tiempo",
    "undoseek-menu-label": "Deshacer búsqueda",
    "play-menu-label": "Reproducir",
    "pause-menu-label": "Pausar",
    "playbackbuttons-menu-label": "Mostrar botones de reproducción",
    "autoplay-menu-label": "Mostrar botón de auto-reproducción",
    "autoplay-guipushbuttonlabel": "Reproducir cuando todos estén listos",
    "autoplay-minimum-label": "Mín. de usuarios:",
    "hideemptyrooms-menu-label": "Hide empty persistent rooms", # TODO: Translate

    "sendmessage-label": "Enviar",

    "ready-guipushbuttonlabel": "¡Estoy listo para ver!",

    "roomuser-heading-label": "Sala / Usuario",
    "size-heading-label": "Tamaño",
    "duration-heading-label": "Duración",
    "filename-heading-label": "Nombre de archivo",
    "notifications-heading-label": "Notificaciones",
    "userlist-heading-label": "Lista de quién reproduce qué",

    "browseformedia-label": "Buscar archivos multimedia",

    "file-menu-label": "&Archivo",  # & precedes shortcut key
    "openmedia-menu-label": "A&brir archivo multimedia",
    "openstreamurl-menu-label": "Abrir URL de &flujo de medios",
    "setmediadirectories-menu-label": "&Establecer directorios de medios",
    "loadplaylistfromfile-menu-label": "&Load playlist from file",  # TODO: Translate
    "saveplaylisttofile-menu-label": "&Save playlist to file",  # TODO: Translate
    "exit-menu-label": "&Salir",
    "advanced-menu-label": "A&vanzado",
    "window-menu-label": "&Ventana",
    "setoffset-menu-label": "Establecer &compensación",
    "createcontrolledroom-menu-label": "C&rear sala administrada",
    "identifyascontroller-menu-label": "&Identificar como operador de sala",
    "settrusteddomains-menu-label": "Es&tablecer dominios de confianza",
    "addtrusteddomain-menu-label": "Agregar {} como dominio de confianza",  # Domain

    "edit-menu-label": "&Edición",
    "cut-menu-label": "Cor&tar",
    "copy-menu-label": "&Copiar",
    "paste-menu-label": "&Pegar",
    "selectall-menu-label": "&Seleccionar todo",

    "playback-menu-label": "Re&producción",

    "help-menu-label": "A&yuda",
    "userguide-menu-label": "Abrir &guía de usuario",
    "update-menu-label": "Buscar actuali&zaciones",

    "startTLS-initiated": "Intentando conexión segura",
    "startTLS-secure-connection-ok": "Conexión segura establecida ({})",
    "startTLS-server-certificate-invalid": 'Falló la conexión segura. El servidor utiliza un certificado inválido. Esta comunicación podría ser interceptada por un tercero. Para más detalles y solución de problemas, consulta <a href="https://syncplay.pl/trouble">aquí</a>.',
    "startTLS-server-certificate-invalid-DNS-ID": "Syncplay does not trust this server because it uses a certificate that is not valid for its hostname.", # TODO: Translate
    "startTLS-not-supported-client": "Este cliente no soporta TLS",
    "startTLS-not-supported-server": "Este servidor no soporta TLS",

    # TLS certificate dialog
    "tls-information-title": "Detalles del certificado",
    "tls-dialog-status-label": "<strong>Syncplay está utilizando una conexión cifrada con {}.</strong>",
    "tls-dialog-desc-label": "El cifrado con un certificado digital, mantiene la información privada cuando se envía hacia o desde<br/>el servidor {}.",
    "tls-dialog-connection-label": "Información cifrada utilizando \"Transport Layer Security\" (TLS), versión {} con la<br/>suite de cifrado: {}.",
    "tls-dialog-certificate-label": "Certificado emitido por {} válido hasta {}.",

    # About dialog
    "about-menu-label": "Acerca de Sy&ncplay",
    "about-dialog-title": "Acerca de Syncplay",
    "about-dialog-release": "Versión {} lanzamiento {}",
    "about-dialog-license-text": "Licenciado bajo la Licencia Apache Versión 2.0",
    "about-dialog-license-button": "Licencia",
    "about-dialog-dependencies": "Dependencias",

    "setoffset-msgbox-label": "Establecer compensación",
    "offsetinfo-msgbox-label": "Compensación (consulta https://syncplay.pl/guide/ para obtener instrucciones de uso):",

    "promptforstreamurl-msgbox-label": "Abrir URL de flujo de medios",
    "promptforstreamurlinfo-msgbox-label": "Publicar URL",

    "addfolder-label": "Agregar carpeta",

    "adduris-msgbox-label": "Agregar URLs a la lista de reproducción (una por línea)",
    "editplaylist-msgbox-label": "Establecer lista de reproducción (una por línea)",
    "trusteddomains-msgbox-label": "Dominios con los cuales está bien intercambiar automáticamente (uno por línea)",

    "createcontrolledroom-msgbox-label": "Crear sala administrada",
    "controlledroominfo-msgbox-label": "Ingresa el nombre de la sala administrada\r\n(consulta https://syncplay.pl/guide/ para obtener instrucciones de uso):",

    "identifyascontroller-msgbox-label": "Identificar como operador de la sala",
    "identifyinfo-msgbox-label": "Ingresa la contraseña de operador para esta sala\r\n(consulta https://syncplay.pl/guide/ para obtener instrucciones de uso):",

    "public-server-msgbox-label": "Selecciona el servidor público para esta sesión de visualización",

    "megabyte-suffix": " MB",

    # Tooltips

    "host-tooltip": "Nombre de host o IP para conectarse, opcionalmente incluyendo puerto (p.ej. syncplay.pl:8999). Sólo sincronizado con personas en el mismo servidor/puerto.",
    "name-tooltip": "Apodo por el que se te conocerá. No hay registro, por lo que puedes cambiarlo fácilmente más tarde. Si no se especifica, se genera un nombre aleatorio.",
    "password-tooltip": "Las contraseñas son sólo necesarias para conectarse a servidores privados.",
    "room-tooltip": "La sala para unirse en la conexión puede ser casi cualquier cosa, pero sólo se sincronizará con las personas en la misma sala.",

    "edit-rooms-tooltip": "Edit room list.", # TO DO: Translate

    "executable-path-tooltip": "Ubicación de tu reproductor multimedia compatible elegido (mpv, mpv.net, VLC, MPC-HC/BE, mplayer2 o IINA).",
    "media-path-tooltip": "Ubicación del video o flujo que se abrirá. Necesario para mplayer2.",
    "player-arguments-tooltip": "Arguementos de línea de comandos adicionales / parámetros para pasar a este reproductor multimedia.",
    "mediasearcdirectories-arguments-tooltip": "Directorios donde Syncplay buscará archivos de medios, p.ej. cuando estás usando la función \"clic para cambiar\". Syncplay buscará recursivamente a través de las subcarpetas.",

    "more-tooltip": "Mostrar configuraciones usadas con menos frecuencia.",
    "filename-privacy-tooltip": "Modo de privacidad para enviar el nombre del archivo que se está reproduciendo actualmente al servidor.",
    "filesize-privacy-tooltip": "Modo de privacidad para enviar el tamaño del archivo que se está reproduciendo actualmente al servidor.",
    "privacy-sendraw-tooltip": "Enviar esta información sin ofuscación. Ésta es la opción predeterminada en la mayoría de las funciones.",
    "privacy-sendhashed-tooltip": "Enviar una versión \"hasheada\" de la información, para que sea menos visible para otros clientes.",
    "privacy-dontsend-tooltip": "No enviar esta información al servidor. Esto proporciona la máxima privacidad.",
    "checkforupdatesautomatically-tooltip": "Regularmente verificar con el sitio Web de Syncplay para ver si hay una nueva versión de Syncplay disponible.",
    "autosavejoinstolist-tooltip": "When you join a room in a server, automatically remember the room name in the list of rooms to join.", # TO DO: Translate
    "slowondesync-tooltip": "Reducir la velocidad de reproducción temporalmente cuando sea necesario, para volver a sincronizar con otros espectadores. No soportado en MPC-HC/BE.",
    "dontslowdownwithme-tooltip": "Significa que otros no se ralentizan ni rebobinan si la reproducción se retrasa. Útil para operadores de la sala.",
    "pauseonleave-tooltip": "Pausa la reproducción si te desconectas o alguien sale de tu sala.",
    "readyatstart-tooltip": "Establecerte como 'listo' al inicio (de lo contrario, se te establecerá como 'no-listo' hasta que cambies tu estado de preparación)",
    "forceguiprompt-tooltip": "El diálogo de configuración no es mostrado cuando se abre un archivo con Syncplay.",  # (Inverted)
    "nostore-tooltip": "Ejecutar Syncplay con la configuración dada, pero no guardar los cambios permanentemente.",  # (Inverted)
    "rewindondesync-tooltip": "Retroceder cuando sea necesario para volver a sincronizar. ¡Deshabilitar esta opción puede resultar en desincronizaciones importantes!",
    "fastforwardondesync-tooltip": "Saltar hacia adelante cuando no está sincronizado con el operador de la sala (o tu posición ficticia 'Nunca ralentizar o rebobinar a otros' está activada).",
    "showosd-tooltip": "Envía mensajes de Syncplay al reproductor multimedia OSD.",
    "showosdwarnings-tooltip": "Mostrar advertencias si se está reproduciendo un archivo diferente, solo en la sala, usuarios no están listos, etc.",
    "showsameroomosd-tooltip": "Mostrar notificaciones de OSD para eventos relacionados con la sala en la que está el usuario.",
    "shownoncontrollerosd-tooltip": "Mostrar notificaciones de OSD para eventos relacionados con no-operadores que están en salas administradas.",
    "showdifferentroomosd-tooltip": "Mostrar notificaciones de OSD para eventos relacionados la sala en la que no está el usuario.",
    "showslowdownosd-tooltip": "Mostrar notificaciones de desaceleración / diferencia de la reversión.",
    "showdurationnotification-tooltip": "Útil cuando falta un segmento de un archivo de varias partes, pero puede dar lugar a falsos positivos.",
    "language-tooltip": "Idioma a ser utilizado por Syncplay.",
    "unpause-always-tooltip": "Si presionas despausar siempre te pone como listo y despausa, en lugar de simplemente ponerte como listo.",
    "unpause-ifalreadyready-tooltip": "Si presionas despausar cuando no estás listo, te pondrá como listo - presiona despausar nuevamente para despausar.",
    "unpause-ifothersready-tooltip": "Si presionas despausar cuando no estás listo, sólo se despausará si los otros están listos.",
    "unpause-ifminusersready-tooltip": "Si presionas despausar cuando no estás listo, sólo se despausará si los otros están listos y se cumple con el mínimo requerido de usuarios.",
    "trusteddomains-arguments-tooltip": "Dominios con los cuales está bien intercambiar automáticamente, cuando las listas de reproducción compartidas están activas.",

    "chatinputenabled-tooltip": "Activa la entrada de chat en mpv (presiona intro para chatear, intro para enviar, escape para cancelar)",
    "chatdirectinput-tooltip": "Omitir tener que presionar 'intro' para ir al modo de entrada de chat en mpv. Presiona TAB en mpv para desactivar temporalmente esta función.",
    "font-label-tooltip": "Fuente utilizada cuando se ingresan mensajes de chat en mpv. Sólo del lado del cliente, por lo que no afecta lo que otros ven.",
    "set-input-font-tooltip": "Familia de fuentes utilizada cuando se ingresan mensajes de chat en mpv. Sólo del lado del cliente, por lo que no afecta lo que otros ven.",
    "set-input-colour-tooltip": "Color de fuente utilizado cuando se ingresan mensajes de chat en mpv. Sólo del lado del cliente, por lo que no afecta lo que otros ven.",
    "chatinputposition-tooltip": "Ubicación en mpv donde aparecerán los mensajes de chat cuando se presione intro y se escriba.",
    "chatinputposition-top-tooltip": "Colocar la entrada del chat en la parte superior de la ventana de mpv.",
    "chatinputposition-middle-tooltip": "Colocar la entrada del chat en el centro muerto de la ventana de mpv.",
    "chatinputposition-bottom-tooltip": "Colocar la entrada del chat en la parte inferior de la ventana de mpv.",
    "chatoutputenabled-tooltip": "Mostrar mensajes de chat en OSD (si está soportado por el reproductor multimedia).",
    "font-output-label-tooltip": "Fuente de salida del chat.",
    "set-output-font-tooltip": "Fuente utilizada para mostrar mensajes de chat.",
    "chatoutputmode-tooltip": "Cómo se muestran los mensajes de chat.",
    "chatoutputmode-chatroom-tooltip": "Mostrar nuevas líneas de chat directamente debajo de la línea anterior.",
    "chatoutputmode-scrolling-tooltip": "Desplazar el texto del chat de derecha a izquierda.",

    "help-tooltip": "Abrir la guía de usuario de Syncplay.pl.",
    "reset-tooltip": "Restablecer todas las configuraciones a la configuración predeterminada.",
    "update-server-list-tooltip": "Conectar a syncplay.pl para actualizar la lista de servidores públicos.",

    "sslconnection-tooltip": "Conectado de forma segura al servidor. Haga clic para obtener los detalles del certificado.",

    "joinroom-tooltip": "Abandonar la sala actual y unirse a la sala especificada.",
    "seektime-msgbox-label": "Saltar al tiempo especificado (en segundos / min:seg). Usar +/- para una búsqueda relativa.",
    "ready-tooltip": "Indica si estás listo para ver.",
    "autoplay-tooltip": "Reproducir automáticamente cuando todos los usuarios que tienen indicador de preparación están listos, y se ha alcanzado el mínimo requerido de usuarios.",
    "switch-to-file-tooltip": "Hacer doble clic para cambiar a {}",  # Filename
    "sendmessage-tooltip": "Enviar mensaje a la sala",

    # In-userlist notes (GUI)
    "differentsize-note": "¡Tamaño diferente!",
    "differentsizeandduration-note": "¡Tamaño y duración diferentes!",
    "differentduration-note": "¡Duración diferente!",
    "nofile-note": "(No se está reproduciendo ningún archivo)",

    # Server messages to client
    "new-syncplay-available-motd-message": "Estás usando Syncplay {} pero hay una versión más nueva disponible en https://syncplay.pl",  # ClientVersion
    "persistent-rooms-notice": "NOTICE: This server uses persistent rooms, which means that the playlist information is stored between playback sessions. If you want to create a room where information is not saved then put -temp at the end of the room name.", # TO DO: Translate - NOTE: Do not translate the word -temp

    # Server notifications
    "welcome-server-notification": "Bienvenido al servidor de Syncplay, ver. {0}",  # version
    "client-connected-room-server-notification": "{0}({2}) conectado a la sala '{1}'",  # username, host, room
    "client-left-server-notification": "{0} abandonó el servidor",  # name
    "no-salt-notification": "IMPORTANTE: Para permitir que las contraseñas del operador de la sala, generadas por esta instancia del servidor, sigan funcionando cuando se reinicie el servidor, por favor en el futuro agregar el siguiente argumento de línea de comandos al ejecutar el servidor de Syncplay: --salt {}",  # Salt


    # Server arguments
    "server-argument-description": 'Solución para sincronizar la reproducción de múltiples instancias de MPlayer y MPC-HC/BE a través de la red. Instancia del servidor',
    "server-argument-epilog": 'Si no se especifican opciones, serán utilizados los valores de _config',
    "server-port-argument": 'puerto TCP del servidor',
    "server-password-argument": 'contraseña del servidor',
    "server-isolate-room-argument": '¿las salas deberían estar aisladas?',
    "server-salt-argument": "cadena aleatoria utilizada para generar contraseñas de salas administradas",
    "server-disable-ready-argument": "deshabilitar la función de preparación",
    "server-motd-argument": "ruta al archivo del cual se obtendrá el texto motd",
    "server-rooms-argument": "path to database file to use and/or create to store persistent room data. Enables rooms to persist without watchers and through restarts", # TODO: Translate
    "server-permanent-rooms-argument": "path to file which lists permenant rooms that will be listed even if the room is empty (in the form of a text file which lists one room per line) - requires persistent rooms to be enabled", # TODO: Translate
    "server-chat-argument": "¿Debería deshabilitarse el chat?",
    "server-chat-maxchars-argument": "Número máximo de caracteres en un mensaje de chat (el valor predeterminado es {})", # Default number of characters
    "server-maxusernamelength-argument": "Número máximo de caracteres para el nombre de usuario (el valor predeterminado es {})",
    "server-stats-db-file-argument": "Habilitar estadísticas del servidor utilizando el archivo db SQLite proporcionado",
    "server-startTLS-argument": "Habilitar conexiones TLS usando los archivos de certificado en la ruta provista",
    "server-messed-up-motd-unescaped-placeholders": "El mensaje del dia contiene marcadores de posición sin escapar. Todos los signos $ deberían ser dobles ($$).",
    "server-messed-up-motd-too-long": "El mensaje del día es muy largo - máximo de {} caracteres, se recibieron {}.",
    "server-listen-only-on-ipv4": "Listen only on IPv4 when starting the server.",
    "server-listen-only-on-ipv6": "Listen only on IPv6 when starting the server.",
    "server-interface-ipv4": "The IP address to bind to for IPv4. Leaving it empty defaults to using all.",
    "server-interface-ipv6": "The IP address to bind to for IPv6. Leaving it empty defaults to using all.",

    # Server errors
    "unknown-command-server-error": "Comando desconocido {}",  # message
    "not-json-server-error": "No es una cadena JSON válida {}",  # message
    "line-decode-server-error": "No es una cadena utf-8",
    "not-known-server-error": "Debes ser reconocido por el servidor antes de enviar este comando",
    "client-drop-server-error": "Caída del cliente: {} -- {}",  # host, error
    "password-required-server-error": "Contraseña requerida",
    "wrong-password-server-error": "Contraseña ingresada incorrecta",
    "hello-server-error": "Not enough Hello arguments",  # DO NOT TRANSLATE

    # Playlists
    "playlist-selection-changed-notification":  "{} cambió la selección de la lista de reproducción",  # Username
    "playlist-contents-changed-notification": "{} actualizó la lista de reproducción",  # Username
    "cannot-find-file-for-playlist-switch-error": "¡No se encontró el archivo {} en el directorio de medios para intercambiar en la lista de reproducción!",  # Filename
    "cannot-add-duplicate-error": "No se pudo agregar una segunda entrada para '{}' a la lista de reproducción ya que no se admiten duplicados.",  # Filename
    "cannot-add-unsafe-path-error": "No se pudo cargar automáticamente {} porque no es un dominio de confianza. Puedes intercambiar la URL manualmente dándole doble clic en la lista de reproducción, y agregar dominios de confianza vía Archivo->Avanzado->Establecer dominios de confianza. Si haces doble clic en una URL entonces puedes agregar su dominio como un dominio de confianza, desde el menú de contexto.",  # Filename
    "sharedplaylistenabled-label": "Activar listas de reproducción compartidas",
    "removefromplaylist-menu-label": "Remover de la lista de reproducción",
    "shuffleremainingplaylist-menu-label": "Mezclar el resto de la lista de reproducción",
    "shuffleentireplaylist-menu-label": "Mezclar toda la lista de reproducción",
    "undoplaylist-menu-label": "Deshacer el último cambio a la lista de reproducción",
    "addfilestoplaylist-menu-label": "Agregar archivo(s) al final de la lista de reproducción",
    "addurlstoplaylist-menu-label": "Agregar URL(s) al final de la lista de reproducción",
    "editplaylist-menu-label": "Editar lista de reproducción",

    "open-containing-folder": "Abrir directorio que contiene este archivo",
    "addyourfiletoplaylist-menu-label": "Agregar tu archivo a la lista de reproducción",
    "addotherusersfiletoplaylist-menu-label": "Agregar el archivo de {} a la lista de reproducción",  # [Username]
    "addyourstreamstoplaylist-menu-label": "Agregar tu flujo a la lista de reproducción",
    "addotherusersstreamstoplaylist-menu-label": "Agregar el flujo de {} a la lista de reproducción",  # [Username]
    "openusersstream-menu-label": "Abrir el flujo de {}",  # [username]'s
    "openusersfile-menu-label": "Abrir el archivo de {}",  # [username]'s

    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate

    "playlist-instruction-item-message": "Desplazar aquí el archivo para agregarlo a la lista de reproducción compartida.",
    "sharedplaylistenabled-tooltip": "Los operadores de la sala pueden agregar archivos a una lista de reproducción sincronizada, para que visualizar la misma cosa sea más sencillo para todos. Configurar directorios multimedia en 'Misc'.",

    "playlist-empty-error": "Playlist is currently empty.", # TO DO: Translate
    "playlist-invalid-index-error": "Invalid playlist index", # TO DO: Translate
}




import os.path
import re
import time
import threading
import _thread
from functools import wraps

import win32con, win32api, win32gui, ctypes, ctypes.wintypes  #@UnresolvedImport @UnusedImport

from syncplay import constants
from syncplay.messages import getMessage
from syncplay.players.basePlayer import BasePlayer
from syncplay.utils import retry


class MpcHcApi:
    def __init__(self):
        self.callbacks = self.__Callbacks()
        self.loadState = None
        self.playState = None
        self.filePlaying = None
        self.fileDuration = None
        self.filePath = None
        self.lastFilePosition = None
        self.version = None
        self.__playpause_warden = False
        self.__locks = self.__Locks()
        self.__mpcExistenceChecking = threading.Thread(target=self.__mpcReadyInSlaveMode, name="Check MPC window")
        self.__mpcExistenceChecking.setDaemon(True)
        self.__listener = self.__Listener(self, self.__locks)
        self.__listener.setDaemon(True)
        self.__listener.start()
        self.__locks.listenerStart.wait()

    def waitForFileStateReady(f):  #@NoSelf
        @wraps(f)
        def wrapper(self, *args, **kwds):
            if not self.__locks.fileReady.wait(constants.MPC_LOCK_WAIT_TIME):
                raise self.PlayerNotReadyException()
            return f(self, *args, **kwds)
        return wrapper

    def startMpc(self, path, args=()):
        args = "%s /slave %s" % (" ".join(args), str(self.__listener.hwnd))
        win32api.ShellExecute(0, "open", path, args, None, 1)
        if not self.__locks.mpcStart.wait(constants.MPC_OPEN_MAX_WAIT_TIME):
            raise self.NoSlaveDetectedException(getMessage("mpc-slave-error"))
        self.__mpcExistenceChecking.start()

    def openFile(self, filePath):
        self.__listener.SendCommand(self.CMD_OPENFILE, filePath)

    def isPaused(self):
        return self.playState != self.__MPC_PLAYSTATE.PS_PLAY and self.playState is not None

    def askForVersion(self):
        self.__listener.SendCommand(self.CMD_GETVERSION)

    @waitForFileStateReady
    def pause(self):
        self.__listener.SendCommand(self.CMD_PAUSE)

    @waitForFileStateReady
    def playPause(self):
        self.__listener.SendCommand(self.CMD_PLAYPAUSE)

    @waitForFileStateReady
    def unpause(self):
        self.__listener.SendCommand(self.CMD_PLAY)

    @waitForFileStateReady
    def askForCurrentPosition(self):
        self.__listener.SendCommand(self.CMD_GETCURRENTPOSITION)

    @waitForFileStateReady
    def seek(self, position):
        self.__listener.SendCommand(self.CMD_SETPOSITION, str(position))

    @waitForFileStateReady
    def setSpeed(self, rate):
        self.__listener.SendCommand(self.CMD_SETSPEED, str(rate))

    def sendOsd(self, message, MsgPos=constants.MPC_OSD_POSITION, DurationMs=(constants.OSD_DURATION*1000)):
        class __OSDDATASTRUCT(ctypes.Structure):
            _fields_ = [
                ('nMsgPos', ctypes.c_int32),
                ('nDurationMS', ctypes.c_int32),
                ('strMsg', ctypes.c_wchar * (len(message.encode('utf-8')) + 1))
            ]
        cmessage = __OSDDATASTRUCT()
        cmessage.nMsgPos = MsgPos
        cmessage.nDurationMS = DurationMs
        cmessage.strMsg = message
        self.__listener.SendCommand(self.CMD_OSDSHOWMESSAGE, cmessage)

    def sendRawCommand(self, cmd, value):
        self.__listener.SendCommand(cmd, value)

    def handleCommand(self, cmd, value):
        if cmd == self.CMD_CONNECT:
            self.__listener.mpcHandle = int(value)
            self.__locks.mpcStart.set()
            if self.callbacks.onConnected:
                _thread.start_new_thread(self.callbacks.onConnected, ())

        elif cmd == self.CMD_STATE:
            self.loadState = int(value)
            fileNotReady = (
                self.loadState == self.__MPC_LOADSTATE.MLS_CLOSING or
                self.loadState == self.__MPC_LOADSTATE.MLS_LOADING or
                self.loadState == self.__MPC_LOADSTATE.MLS_CLOSED
            )
            if fileNotReady:
                self.playState = None
                self.__locks.fileReady.clear()
            else:
                self.__locks.fileReady.set()
            if self.callbacks.onFileStateChange:
                _thread.start_new_thread(self.callbacks.onFileStateChange, (self.loadState,))

        elif cmd == self.CMD_PLAYMODE:
            self.playState = int(value)
            if self.callbacks.onUpdatePlaystate:
                _thread.start_new_thread(self.callbacks.onUpdatePlaystate, (self.playState,))

        elif cmd == self.CMD_NOWPLAYING:
            value = re.split(r'(?<!\\)\|', value)
            if self.filePath == value[3]:
                return
            self.filePath = value[3]
            self.filePlaying = value[3].split('\\').pop()
            self.fileDuration = float(value[4])
            if self.callbacks.onUpdatePath:
                _thread.start_new_thread(self.callbacks.onUpdatePath, (self.onUpdatePath,))
            if self.callbacks.onUpdateFilename:
                _thread.start_new_thread(self.callbacks.onUpdateFilename, (self.filePlaying,))
            if self.callbacks.onUpdateFileDuration:
                _thread.start_new_thread(self.callbacks.onUpdateFileDuration, (self.fileDuration,))

        elif cmd == self.CMD_CURRENTPOSITION:
            self.lastFilePosition = float(value)
            if self.callbacks.onGetCurrentPosition:
                _thread.start_new_thread(self.callbacks.onGetCurrentPosition, (self.lastFilePosition,))

        elif cmd == self.CMD_NOTIFYSEEK:
            if self.lastFilePosition != float(value):  # Notify seek is sometimes sent twice
                self.lastFilePosition = float(value)
                if self.callbacks.onSeek:
                    _thread.start_new_thread(self.callbacks.onSeek, (self.lastFilePosition,))

        elif cmd == self.CMD_DISCONNECT:
            if self.callbacks.onMpcClosed:
                _thread.start_new_thread(self.callbacks.onMpcClosed, (None,))

        elif cmd == self.CMD_VERSION:
            if self.callbacks.onVersion:
                self.version = value
                _thread.start_new_thread(self.callbacks.onVersion, (value,))

    class PlayerNotReadyException(Exception):
        pass

    class __Callbacks:
        def __init__(self):
            self.onConnected = None
            self.onSeek = None
            self.onUpdatePath = None
            self.onUpdateFilename = None
            self.onUpdateFileDuration = None
            self.onGetCurrentPosition = None
            self.onUpdatePlaystate = None
            self.onFileStateChange = None
            self.onMpcClosed = None
            self.onVersion = None

    class __Locks:
        def __init__(self):
            self.listenerStart = threading.Event()
            self.mpcStart = threading.Event()
            self.fileReady = threading.Event()

    def __mpcReadyInSlaveMode(self):
        while True:
            time.sleep(10)
            if not win32gui.IsWindow(self.__listener.mpcHandle):
                if self.callbacks.onMpcClosed:
                    self.callbacks.onMpcClosed(None)
                break

    CMD_CONNECT = 0x50000000
    CMD_STATE = 0x50000001
    CMD_PLAYMODE = 0x50000002
    CMD_NOWPLAYING = 0x50000003
    CMD_LISTSUBTITLETRACKS = 0x50000004
    CMD_LISTAUDIOTRACKS = 0x50000005
    CMD_CURRENTPOSITION = 0x50000007
    CMD_NOTIFYSEEK = 0x50000008
    CMD_NOTIFYENDOFSTREAM = 0x50000009
    CMD_PLAYLIST = 0x50000006
    CMD_OPENFILE = 0xA0000000
    CMD_STOP = 0xA0000001
    CMD_CLOSEFILE = 0xA0000002
    CMD_PLAYPAUSE = 0xA0000003
    CMD_ADDTOPLAYLIST = 0xA0001000
    CMD_CLEARPLAYLIST = 0xA0001001
    CMD_STARTPLAYLIST = 0xA0001002
    CMD_REMOVEFROMPLAYLIST = 0xA0001003  # TODO
    CMD_SETPOSITION = 0xA0002000
    CMD_SETAUDIODELAY = 0xA0002001
    CMD_SETSUBTITLEDELAY = 0xA0002002
    CMD_SETINDEXPLAYLIST = 0xA0002003  # DOESNT WORK
    CMD_SETAUDIOTRACK = 0xA0002004
    CMD_SETSUBTITLETRACK = 0xA0002005
    CMD_GETSUBTITLETRACKS = 0xA0003000
    CMD_GETCURRENTPOSITION = 0xA0003004
    CMD_JUMPOFNSECONDS = 0xA0003005
    CMD_GETAUDIOTRACKS = 0xA0003001
    CMD_GETNOWPLAYING = 0xA0003002
    CMD_GETPLAYLIST = 0xA0003003
    CMD_TOGGLEFULLSCREEN = 0xA0004000
    CMD_JUMPFORWARDMED = 0xA0004001
    CMD_JUMPBACKWARDMED = 0xA0004002
    CMD_INCREASEVOLUME = 0xA0004003
    CMD_DECREASEVOLUME = 0xA0004004
    CMD_SHADER_TOGGLE = 0xA0004005
    CMD_CLOSEAPP = 0xA0004006
    CMD_OSDSHOWMESSAGE = 0xA0005000
    CMD_VERSION = 0x5000000A
    CMD_DISCONNECT = 0x5000000B
    CMD_PLAY = 0xA0000004
    CMD_PAUSE = 0xA0000005
    CMD_GETVERSION = 0xA0003006
    CMD_SETSPEED = 0xA0004008

    class __MPC_LOADSTATE:
        MLS_CLOSED = 0
        MLS_LOADING = 1
        MLS_LOADED = 2
        MLS_CLOSING = 3

    class __MPC_PLAYSTATE:
        PS_PLAY = 0
        PS_PAUSE = 1
        PS_STOP = 2
        PS_UNUSED = 3

    class __Listener(threading.Thread):
        def __init__(self, mpcApi, locks):
            self.__mpcApi = mpcApi
            self.locks = locks
            self.mpcHandle = None
            self.hwnd = None
            self.__PCOPYDATASTRUCT = ctypes.POINTER(self.__COPYDATASTRUCT)
            threading.Thread.__init__(self, name="MPC Listener")

        def run(self):
            message_map = {
                win32con.WM_COPYDATA: self.OnCopyData
            }
            wc = win32gui.WNDCLASS()
            wc.lpfnWndProc = message_map
            wc.lpszClassName = 'MPCApiListener'
            hinst = wc.hInstance = win32api.GetModuleHandle(None)
            classAtom = win32gui.RegisterClass(wc)
            self.hwnd = win32gui.CreateWindow(
                classAtom,
                "ListenerGUI",
                0,
                0,
                0,
                win32con.CW_USEDEFAULT,
                win32con.CW_USEDEFAULT,
                0,
                0,
                hinst,
                None
            )
            self.locks.listenerStart.set()
            win32gui.PumpMessages()

        def OnCopyData(self, hwnd, msg, wparam, lparam):
            pCDS = ctypes.cast(lparam, self.__PCOPYDATASTRUCT)
            # print "API:\tin>\t 0x%X\t" % int(pCDS.contents.dwData), ctypes.wstring_at(pCDS.contents.lpData)
            self.__mpcApi.handleCommand(pCDS.contents.dwData, ctypes.wstring_at(pCDS.contents.lpData))
            return 0

        def SendCommand(self, cmd, message=''):
            # print "API:\t<out\t 0x%X\t" % int(cmd), message
            if not win32gui.IsWindow(self.mpcHandle):
                if self.__mpcApi.callbacks.onMpcClosed:
                    self.__mpcApi.callbacks.onMpcClosed(None)
            cs = self.__COPYDATASTRUCT()
            cs.dwData = cmd;

            if isinstance(message, str):
                message = ctypes.create_unicode_buffer(message, len(message) + 1)
            elif isinstance(message, ctypes.Structure):
                pass
            else:
                raise TypeError
            cs.lpData = ctypes.addressof(message)
            cs.cbData = ctypes.sizeof(message)
            ptr = ctypes.addressof(cs)
            win32api.SendMessage(self.mpcHandle, win32con.WM_COPYDATA, self.hwnd, ptr)

        class __COPYDATASTRUCT(ctypes.Structure):
            _fields_ = [
                ('dwData', ctypes.wintypes.LPARAM),
                ('cbData', ctypes.wintypes.DWORD),
                ('lpData', ctypes.c_void_p)
            ]


class MPCHCAPIPlayer(BasePlayer):
    speedSupported = False
    alertOSDSupported = False
    customOpenDialog = False
    chatOSDSupported = False
    osdMessageSeparator = "; "

    def __init__(self, client):
        from twisted.internet import reactor
        self.reactor = reactor
        self.__client = client
        self._mpcApi = MpcHcApi()
        self._mpcApi.callbacks.onUpdateFilename = lambda _: self.__makePing()
        self._mpcApi.callbacks.onMpcClosed = lambda _: self.reactor.callFromThread(self.__client.stop, False,)
        self._mpcApi.callbacks.onFileStateChange = lambda _: self.__lockAsking()
        self._mpcApi.callbacks.onUpdatePlaystate = lambda _: self.__unlockAsking()
        self._mpcApi.callbacks.onGetCurrentPosition = lambda _: self.__onGetPosition()
        self._mpcApi.callbacks.onVersion = lambda _: self.__versionUpdate.set()
        self.__switchPauseCalls = False
        self.__preventAsking = threading.Event()
        self.__positionUpdate = threading.Event()
        self.__versionUpdate = threading.Event()
        self.__fileUpdate = threading.RLock()
        self.__versionUpdate.clear()

    @staticmethod
    def getMinVersionErrorMessage():
        return getMessage("mpc-version-insufficient-error").format(constants.MPC_MIN_VER)

    def drop(self):
        self.__preventAsking.set()
        self.__positionUpdate.set()
        self.__versionUpdate.set()
        self._mpcApi.sendRawCommand(MpcHcApi.CMD_CLOSEAPP, "")

    @staticmethod
    def getPlayerPathErrors(playerPath, filePath):
        return None

    @staticmethod
    def run(client, playerPath, filePath, args):
        args.extend(['/open', '/new'])
        mpc = MPCHCAPIPlayer(client)
        mpc._mpcApi.callbacks.onConnected = lambda: mpc.initPlayer(filePath if filePath else None)
        mpc._mpcApi.startMpc(MPCHCAPIPlayer.getExpandedPath(playerPath), args)
        client.initPlayer(mpc)
        return mpc

    def __lockAsking(self):
        self.__preventAsking.clear()

    def __unlockAsking(self):
        self.__preventAsking.set()

    def __onGetPosition(self):
        self.__positionUpdate.set()

    def setSpeed(self, value):
        try:
            self._mpcApi.setSpeed(value)
        except MpcHcApi.PlayerNotReadyException:
            self.setSpeed(value)

    def __dropIfNotSufficientVersion(self):
        self._mpcApi.askForVersion()
        if not self.__versionUpdate.wait(0.1) or not self._mpcApi.version:
            self.reactor.callFromThread(self.__client.ui.showErrorMessage, self.getMinVersionErrorMessage(), True)
            self.reactor.callFromThread(self.__client.stop, True)

    def __testMpcReady(self):
        if not self.__preventAsking.wait(10):
            raise Exception(getMessage("player-file-open-error"))

    def __makePing(self):
        try:
            self.__testMpcReady()
            self._mpcApi.callbacks.onUpdateFilename = lambda _: self.__handleUpdatedFilename()
            self.__handleUpdatedFilename()
            self.askForStatus()
        except Exception as err:
            self.reactor.callFromThread(self.__client.ui.showErrorMessage, err.message, True)
            self.reactor.callFromThread(self.__client.stop)

    def initPlayer(self, filePath):
        self.__dropIfNotSufficientVersion()
        if not self._mpcApi.version:
            return
        self.__mpcVersion = self._mpcApi.version.split('.')
        if self.__mpcVersion[0:3] == ['1', '6', '4']:
            self.__switchPauseCalls = True
        if filePath:
            self.openFile(filePath)

    def openFile(self, filePath, resetPosition=False):
        self._mpcApi.openFile(filePath)
        if resetPosition and self._mpcApi.filePlaying:
            self.setPosition(0, resetPosition=True)

    def displayMessage(
        self, message,
        duration=(constants.OSD_DURATION*1000), OSDType=constants.OSD_NOTIFICATION, mood=constants.MESSAGE_NEUTRAL
    ):
        self._mpcApi.sendOsd(message, constants.MPC_OSD_POSITION, duration)

    @retry(MpcHcApi.PlayerNotReadyException, constants.MPC_MAX_RETRIES, constants.MPC_RETRY_WAIT_TIME, 1)
    def setPaused(self, value):
        if self._mpcApi.filePlaying:
            if self.__switchPauseCalls:
                value = not value
            if value:
                self._mpcApi.pause()
            else:
                self._mpcApi.unpause()

    def setFeatures(self, featureList):
        pass

    @retry(MpcHcApi.PlayerNotReadyException, constants.MPC_MAX_RETRIES, constants.MPC_RETRY_WAIT_TIME, 1)
    def setPosition(self, value, resetPosition=False):
        if self._mpcApi.filePlaying:
            self._mpcApi.seek(value)
        elif resetPosition:
            raise MpcHcApi.PlayerNotReadyException()

    def __getPosition(self):
        self.__positionUpdate.clear()
        self._mpcApi.askForCurrentPosition()
        self.__positionUpdate.wait(constants.MPC_LOCK_WAIT_TIME)
        return self._mpcApi.lastFilePosition

    def askForStatus(self):
        try:
            if self._mpcApi.filePlaying and self.__preventAsking.wait(0) and self.__fileUpdate.acquire(0):
                self.__fileUpdate.release()
                position = self.__getPosition()
                paused = self._mpcApi.isPaused()
                position = float(position)
                if self.__preventAsking.wait(0) and self.__fileUpdate.acquire(0):
                    self.__client.updatePlayerStatus(paused, position)
                    self.__fileUpdate.release()
            else:
                self.__echoGlobalStatus()
        except MpcHcApi.PlayerNotReadyException:
            self.__echoGlobalStatus()

    def __echoGlobalStatus(self):
        self.__client.updatePlayerStatus(self.__client.getGlobalPaused(), self.__client.getGlobalPosition())

    def __forcePause(self):
        for _ in range(constants.MPC_MAX_RETRIES):
            self.setPaused(True)
            time.sleep(constants.MPC_RETRY_WAIT_TIME)

    def __refreshMpcPlayState(self):
        for _ in range(2):
            self._mpcApi.playPause()
            time.sleep(constants.MPC_PAUSE_TOGGLE_DELAY)

    def _setPausedAccordinglyToServer(self):
        self.__forcePause()
        self.setPaused(self.__client.getGlobalPaused())
        if self._mpcApi.isPaused() != self.__client.getGlobalPaused():
            self.__refreshMpcPlayState()
            if self._mpcApi.isPaused() != self.__client.getGlobalPaused():
                self.__setUpStateForNewlyOpenedFile()

    @retry(MpcHcApi.PlayerNotReadyException, constants.MPC_MAX_RETRIES, constants.MPC_RETRY_WAIT_TIME, 1)
    def __setUpStateForNewlyOpenedFile(self):
        self._setPausedAccordinglyToServer()
        self._mpcApi.seek(self.__client.getGlobalPosition())

    def __handleUpdatedFilename(self):
        with self.__fileUpdate:
            self.__setUpStateForNewlyOpenedFile()
            args = (self._mpcApi.filePlaying, self._mpcApi.fileDuration, self._mpcApi.filePath)
            self.reactor.callFromThread(self.__client.updateFile, *args)

    def sendCustomCommand(self, cmd, val):
        self._mpcApi.sendRawCommand(cmd, val)

    @staticmethod
    def getDefaultPlayerPathsList():
        return constants.MPC_PATHS

    @staticmethod
    def getIconPath(path):
        lower_path = MPCHCAPIPlayer.getExpandedPath(path).lower()
        for mpc_64_filename in constants.MPC64_EXECUTABLES:
            if lower_path.endswith(mpc_64_filename):
                return constants.MPC64_ICONPATH
        return constants.MPC_ICONPATH

    @staticmethod
    def isValidPlayerPath(path):
        if MPCHCAPIPlayer.getExpandedPath(path):
            return True
        return False

    @staticmethod
    def getExpandedPath(path):
        lower_path = path.lower()
        if os.path.isfile(path):
            for mpc_executable_filename in constants.MPC_EXECUTABLES:
                if lower_path.endswith(mpc_executable_filename):
                    return path
        for mpc_executable_filename in constants.MPC_EXECUTABLES:
            if os.path.isfile(path + mpc_executable_filename):
                path += mpc_executable_filename
                return path
            elif os.path.isfile(path + "\\" +  mpc_executable_filename):
                path += "\\" + mpc_executable_filename
                return path
